<?php defined('ABSPATH') || exit;

/**
 * Class JKD_ACF
 */
class JKD_ACF extends JKD_Core
{

    /**
     * JKD_ACF constructor.
     */
    public function __construct()
    {

        /* templates settings */
        $this->add_templates_settings();

        /* menu settings */
        $this->add_menu_settings();

        /* page header settings */
        $this->add_page_header_settings();

        /* post settings */
        $this->add_post_settings();

        /* career settings */
        $this->add_career_settings();

        /* portfolio settings */
        $this->add_portfolio_settings();

        $this->add_navigation_settings();

        $this->add_footer_settings();

        $this->add_global_settings();

        if (class_exists('WooCommerce')):

            $this->add_product_settings();

        endif;

    }

    /**
     *
     */
    public function add_career_settings()
    {

        if (function_exists('acf_add_local_field_group')):

            acf_add_local_field_group(array(
                'key' => 'group_career_settings',
                'title' => __('Position Options', 'jkd-core'),
                'location' => array(
                    array(
                        array(
                            'param' => 'post_type',
                            'operator' => '==',
                            'value' => 'career',
                        ),
                    ),
                ),
                'position' => 'side',
            ));

        endif;

        if (function_exists('acf_add_local_field')):

            acf_add_local_field(array(
                'key' => 'field_position_location',
                'label' => esc_html__('Position Location', 'jkd-core'),
                'name' => 'option_position_location',
                'type' => 'text',
                'instructions' => esc_html__('Input position location', 'jkd-core'),
                'required' => 0,
                'conditional_logic' => 0,
                'parent' => 'group_career_settings',
            ));

            acf_add_local_field(array(
                'key' => 'field_position_category',
                'label' => esc_html__('Position Category', 'jkd-core'),
                'name' => 'option_position_category',
                'type' => 'text',
                'instructions' => esc_html__('Input position category', 'jkd-core'),
                'required' => 0,
                'conditional_logic' => 0,
                'parent' => 'group_career_settings',
            ));

            acf_add_local_field(array(
                'key' => 'field_position_working_hours',
                'label' => esc_html__('Position Working Hours', 'jkd-core'),
                'name' => 'option_position_working_hours',
                'type' => 'text',
                'instructions' => esc_html__('Input position working hours', 'jkd-core'),
                'required' => 0,
                'conditional_logic' => 0,
                'parent' => 'group_career_settings',
            ));

        endif;

    }

    /**
     *
     */
    public function add_product_settings()
    {

        if (function_exists('acf_add_local_field_group')):

            acf_add_local_field_group(array(
                'key' => 'group_product_settings',
                'title' => __('Product Options', 'jkd-core'),
                'location' => array(
                    array(
                        array(
                            'param' => 'taxonomy',
                            'operator' => '==',
                            'value' => 'product_cat',
                        ),
                    ),
                ),
                'position' => 'side',
            ));

        endif;

        if (function_exists('acf_add_local_field')):

            acf_add_local_field_group(array(
                'key' => 'group_product_page_labels_settings',
                'title' => esc_html__('Product Labels', 'jkd-core'),
                'fields' => array(
                    array(
                        'key' => 'field_new_label',
                        'label' => esc_html__('New Label', 'jkd-core'),
                        'name' => 'option_new_label',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the "New" product label', 'jkd-core'),
                        'required' => 0,
                        'conditional_logic' => 0,
                        'default_value' => 0,
                        'ui' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                ),
                'location' => array(
                    array(
                        array(
                            'param' => 'post_type',
                            'operator' => '==',
                            'value' => 'product',
                        ),
                    ),
                ),
                'menu_order' => 0,
                'position' => 'side',
                'style' => 'default',
                'label_placement' => 'top',
                'instruction_placement' => 'label',
                'hide_on_screen' => '',
                'active' => true,
                'description' => '',
            ));

            acf_add_local_field_group(array(
                'key' => 'group_video_product_settings',
                'title' => esc_html__('Video Gallery', 'jkd-core'),
                'fields' => array(
                    array(
                        'key' => 'field_product_video_gallery',
                        'label' => esc_html__('Video', 'jkd-core'),
                        'name' => 'option_product_video_gallery',
                        'type' => 'repeater',
                        'required' => 0,
                        'conditional_logic' => 0,
                        'min' => 0,
                        'max' => 0,
                        'layout' => 'row',
                        'sub_fields' => array(
                            array(
                                'key' => 'field_product_video_preview',
                                'label' => esc_html__('Video Preview', 'jkd-core'),
                                'name' => 'option_product_video_preview',
                                'type' => 'image',
                                'required' => 0,
                                'conditional_logic' => 0,
                                'return_format' => 'array',
                                'preview_size' => 'medium',
                                'library' => 'all',
                            ),
                            array(
                                'key' => 'field_product_video_index',
                                'label' => esc_html__('Video Index', 'jkd-core'),
                                'name' => 'option_product_video_index',
                                'type' => 'number',
                                'required' => 0,
                                'conditional_logic' => 0,
                                'default_value' => 1,
                            ),
                            array(
                                'key' => 'field_product_video',
                                'label' => esc_html__('Video', 'jkd-core'),
                                'name' => 'option_product_video',
                                'type' => 'button_group',
                                'choices' => array(
                                    'html' => esc_html('Html'),
                                    'youtube' => esc_html('Youtube'),
                                    'vimeo' => esc_html('Vimeo'),
                                ),
                                'default_value' => 'html',
                                'layout' => 'horizontal',
                                'return_format' => 'value',
                            ),
                            array(
                                'key' => 'field_product_video_file',
                                'label' => esc_html__('HTML Video', 'jkd-core'),
                                'name' => 'option_product_video_file',
                                'type' => 'file',
                                'conditional_logic' => array(
                                    array(
                                        array(
                                            'field' => 'field_product_video',
                                            'operator' => '==',
                                            'value' => 'html',
                                        ),
                                    ),
                                ),
                                'return_format' => 'url',
                                'library' => 'all',
                            ),
                            array(
                                'key' => 'field_product_video_url',
                                'label' => esc_html__('Video URL', 'jkd-core'),
                                'name' => 'option_product_video_url',
                                'type' => 'url',
                                'conditional_logic' => array(
                                    array(
                                        array(
                                            'field' => 'field_product_video',
                                            'operator' => '==',
                                            'value' => 'youtube',
                                        ),
                                    ),
                                    array(
                                        array(
                                            'field' => 'field_product_video',
                                            'operator' => '==',
                                            'value' => 'vimeo',
                                        ),
                                    ),
                                ),
                            ),
                        ),
                    ),
                ),
                'location' => array(
                    array(
                        array(
                            'param' => 'post_type',
                            'operator' => '==',
                            'value' => 'product',
                        ),
                    ),
                ),
                'menu_order' => 0,
                'position' => 'side',
                'style' => 'default',
                'label_placement' => 'top',
                'instruction_placement' => 'label',
                'active' => true,
            ));

        endif;

    }

    /**
     * add menu settings
     */
    public function add_menu_settings()
    {

        /* check if exists ACF */
        if (class_exists('ACF')):

            /* menu item settings group */
            acf_add_local_field_group(array(
                'key' => 'group_menu_item_settings',
                'title' => __('Menu Item Options', 'jkd-core'),
                'fields' => array(
                    array(
                        'key' => 'field_menu_megamenu_toggle',
                        'label' => esc_html__('Megamenu', 'jkd-core'),
                        'name' => 'option_menu_megamenu_toggle',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the megamenu', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 0,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                    array(
                        'key' => 'field_menu_item_label_toggle',
                        'label' => esc_html__('Menu Item Label', 'jkd-core'),
                        'name' => 'option_menu_item_label_toggle',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the menu item label', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 0,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                    array(
                        'key' => 'field_menu_item_label',
                        'label' => esc_html__('Label Text', 'jkd-core'),
                        'name' => 'option_menu_item_label',
                        'type' => 'text',
                        'instructions' => esc_html__('Input menu item label text', 'jkd-core'),
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_menu_item_label_toggle',
                                    'operator' => '==',
                                    'value' => '1',
                                ),
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_menu_item_label_color',
                        'label' => esc_html__('Label Color', 'jkd-core'),
                        'name' => 'option_menu_item_label_color',
                        'type' => 'color_picker',
                        'instructions' => esc_html__('Select menu item label color', 'jkd-core'),
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_menu_item_label_toggle',
                                    'operator' => '==',
                                    'value' => '1',
                                ),
                            ),
                        ),
                    ),
                ),
                'location' => array(
                    array(
                        array(
                            'param' => 'nav_menu_item',
                            'operator' => '==',
                            'value' => 'all',
                        ),
                    ),
                ),
            ));

        endif;

    }

    /**
     * add navigation settings
     */
    public function add_navigation_settings()
    {

        /* check if exists ACF */
        if (class_exists('ACF')):

            /* menu item settings group */
            acf_add_local_field_group(array(
                'key' => 'group_navigation_settings',
                'title' => __('Navigation', 'jkd-core'),
                'location' => array(
                    array(
                        array(
                            'param' => 'post_type',
                            'operator' => '==',
                            'value' => 'all',
                        ),
                    ),
                ),
                'position' => 'side',
                'fields' => array(
                    array(
                        'key' => 'field_before_content_toggle',
                        'label' => esc_html__('Before Content Sections', 'jkd-core'),
                        'name' => 'option_before_content_toggle',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the before-content sections', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                    array(
                        'key' => 'field_navigation',
                        'label' => esc_html__('Navigation', 'jkd-core'),
                        'name' => 'option_navigation',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the navigation', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                    array(
                        'key' => 'field_navigation_type',
                        'label' => esc_html__('Navigation Type', 'jkd-core'),
                        'name' => 'option_navigation_type',
                        'type' => 'select',
                        'required' => 0,
                        'choices' => array(
                            'default' => esc_html__('Default', 'jkd-core'),
                            'overlay' => esc_html__('Overlay', 'jkd-core'),
                            'side' => esc_html__('Side', 'jkd-core'),
                        ),
                        'default_value' => false,
                        'allow_null' => 0,
                        'multiple' => 0,
                        'ui' => 1,
                        'ajax' => 0,
                        'return_format' => 'value',
                        'placeholder' => esc_html__('Navigation Type', 'jkd-core'),
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_navigation',
                                    'operator' => '==',
                                    'value' => '1',
                                ),
                            ),
                        ),
                    ),
                ),
            ));

        endif;

    }

    /**
     * add page header settings
     */
    public function add_page_header_settings()
    {

        /* check if exists ACF */
        if (class_exists('ACF')):

            /* menu item settings group */
            acf_add_local_field_group(array(
                'key' => 'group_page_header_settings',
                'title' => __('Page Header', 'jkd-core'),
                'location' => array(
                    array(
                        array(
                            'param' => 'post_type',
                            'operator' => '==',
                            'value' => 'all',
                        ),
                        array(
                            'param' => 'post_type',
                            'operator' => '!=',
                            'value' => 'tribe_events',
                        ),
                    ),
                ),
                'position' => 'side',
                'fields' => array(
                    array(
                        'key' => 'field_page_header',
                        'label' => esc_html__('Page Header', 'jkd-core'),
                        'name' => 'option_page_header',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the page header', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 0,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                    array(
                        'key' => 'field_page_header_style',
                        'label' => esc_html__('Style', 'jkd-core'),
                        'name' => 'option_page_header_style',
                        'type' => 'select',
                        'choices' => array(
                            'default' => esc_html__('Default', 'jkd-core'),
                            'classic' => esc_html__('Classic', 'jkd-core'),
                            'minimal' => esc_html__('Minimal', 'jkd-core'),
                            'image' => esc_html__('Image', 'jkd-core'),
                        ),
                        'default_value' => false,
                        'ui' => 1,
                        'return_format' => 'value',
                        'placeholder' => esc_html__('Page Header Style', 'jkd-core'),
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_page_header',
                                    'operator' => '==',
                                    'value' => '1',
                                ),
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_page_header_image',
                        'label' => esc_html__('Page Header Image', 'jkd-core'),
                        'name' => 'option_page_header_image',
                        'type' => 'image',
                        'instructions' => esc_html__('Upload header image', 'jkd-core'),
                        'return_format' => 'id',
                        'preview_size' => 'thumbnail',
                        'library' => 'all',
                        'parent' => 'group_product_settings',
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_page_header',
                                    'operator' => '==',
                                    'value' => '1',
                                ),
                                array(
                                    'field' => 'field_page_header_style',
                                    'operator' => '==',
                                    'value' => 'image',
                                ),
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_page_header_parallax',
                        'label' => esc_html__('Enable Parallax', 'jkd-core'),
                        'name' => 'option_page_header_parallax',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the image parallax', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => '1',
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_page_header',
                                    'operator' => '==',
                                    'value' => '1',
                                ),
                                array(
                                    'field' => 'field_page_header_style',
                                    'operator' => '==',
                                    'value' => 'image',
                                ),
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_page_header_alignment',
                        'label' => esc_html__('Alignment', 'jkd-core'),
                        'name' => 'option_page_header_alignment',
                        'type' => 'button_group',
                        'choices' => array(
                            'left' => esc_html__('Left', 'jkd-core'),
                            'center' => esc_html__('Center', 'jkd-core'),
                            'right' => esc_html__('Right', 'jkd-core'),
                        ),
                        'default_value' => false,
                        'ui' => 1,
                        'return_format' => 'value',
                        'placeholder' => esc_html__('Page Header Alignment', 'jkd-core'),
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_page_header',
                                    'operator' => '==',
                                    'value' => '1',
                                ),
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_page_header_breadcrumbs',
                        'label' => esc_html__('Breadcrumbs', 'jkd-core'),
                        'name' => 'option_page_header_breadcrumbs',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the breadcrumbs', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => false,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_page_header',
                                    'operator' => '==',
                                    'value' => '1',
                                ),
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_page_header_bottom_border',
                        'label' => esc_html__('Enable Bottom Border', 'jkd-core'),
                        'name' => 'option_page_header_bottom_border',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the bottom border', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => '1',
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_page_header',
                                    'operator' => '==',
                                    'value' => '1',
                                ),
                            ),
                        ),
                    ),
                ),
            ));

        endif;

    }

    /**
     * add page header settings
     */
    public function add_post_settings()
    {

        /* check if exists ACF */
        if (class_exists('ACF')):

            acf_add_local_field_group(array(
                'key' => 'group_gallery_post_settings',
                'title' => esc_html__('Gallery Settings', 'jkd-core'),
                'fields' => array(
                    array(
                        'key' => 'field_post_gallery',
                        'label' => esc_html__('Gallery', 'jkd-core'),
                        'name' => 'option_post_gallery',
                        'type' => 'gallery',
                        'return_format' => 'id',
                        'preview_size' => 'medium',
                        'insert' => 'append',
                        'library' => 'all',
                    ),
                ),
                'location' => array(
                    array(
                        array(
                            'param' => 'post_type',
                            'operator' => '==',
                            'value' => 'post',
                        ),
                        array(
                            'param' => 'post_format',
                            'operator' => '==',
                            'value' => 'gallery',
                        ),
                    ),
                ),
                'menu_order' => 0,
                'position' => 'side',
                'style' => 'default',
                'label_placement' => 'top',
                'instruction_placement' => 'label',
                'active' => true,
            ));

            acf_add_local_field_group(array(
                'key' => 'group_audio_post_settings',
                'title' => esc_html__('Audio Settings', 'jkd-core'),
                'fields' => array(
                    array(
                        'key' => 'field_post_audio_file',
                        'label' => esc_html__('Audio', 'jkd-core'),
                        'name' => 'option_post_audio_file',
                        'type' => 'file',
                        'return_format' => 'url',
                        'library' => 'all',
                    ),
                ),
                'location' => array(
                    array(
                        array(
                            'param' => 'post_type',
                            'operator' => '==',
                            'value' => 'post',
                        ),
                        array(
                            'param' => 'post_format',
                            'operator' => '==',
                            'value' => 'audio',
                        ),
                    ),
                ),
                'menu_order' => 0,
                'position' => 'side',
                'style' => 'default',
                'label_placement' => 'top',
                'instruction_placement' => 'label',
                'active' => true,
            ));

            acf_add_local_field_group(array(
                'key' => 'group_video_post_settings',
                'title' => esc_html__('Video Settings', 'jkd-core'),
                'fields' => array(
                    array(
                        'key' => 'field_post_video',
                        'label' => esc_html__('Video', 'jkd-core'),
                        'name' => 'option_post_video',
                        'type' => 'button_group',
                        'choices' => array(
                            'html' => esc_html('Html'),
                            'youtube' => esc_html('Youtube'),
                            'vimeo' => esc_html('Vimeo'),
                        ),
                        'default_value' => 'html',
                        'layout' => 'horizontal',
                        'return_format' => 'value',
                    ),
                    array(
                        'key' => 'field_post_video_file',
                        'label' => esc_html__('HTML Video', 'jkd-core'),
                        'name' => 'option_post_video_file',
                        'type' => 'file',
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_post_video',
                                    'operator' => '==',
                                    'value' => 'html',
                                ),
                            ),
                        ),
                        'return_format' => 'url',
                        'library' => 'all',
                    ),
                    array(
                        'key' => 'field_post_video_url',
                        'label' => esc_html__('Video URL', 'jkd-core'),
                        'name' => 'option_post_video_url',
                        'type' => 'url',
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_post_video',
                                    'operator' => '==',
                                    'value' => 'youtube',
                                ),
                            ),
                            array(
                                array(
                                    'field' => 'field_post_video',
                                    'operator' => '==',
                                    'value' => 'vimeo',
                                ),
                            ),
                        ),
                    ),
                ),
                'location' => array(
                    array(
                        array(
                            'param' => 'post_type',
                            'operator' => '==',
                            'value' => 'post',
                        ),
                        array(
                            'param' => 'post_format',
                            'operator' => '==',
                            'value' => 'video',
                        ),
                    ),
                ),
                'menu_order' => 0,
                'position' => 'side',
                'style' => 'default',
                'label_placement' => 'top',
                'instruction_placement' => 'label',
                'active' => true,
            ));

            acf_add_local_field_group(array(
                'key' => 'group_meta_post_settings',
                'title' => esc_html__('Meta Settings', 'jkd-core'),
                'fields' => array(
                    array(
                        'key' => 'field_author',
                        'label' => esc_html__('Author', 'jkd-core'),
                        'name' => 'option_author',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the author meta box', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                    array(
                        'key' => 'field_date',
                        'label' => esc_html__('Date', 'jkd-core'),
                        'name' => 'option_date',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the date meta box', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                    array(
                        'key' => 'field_last_update',
                        'label' => esc_html__('Last Update', 'jkd-core'),
                        'name' => 'option_last_update',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the last update meta box', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                    array(
                        'key' => 'field_reading_time',
                        'label' => esc_html__('Reading Time', 'jkd-core'),
                        'name' => 'option_reading_time',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the reading meta box', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                    array(
                        'key' => 'field_categories',
                        'label' => esc_html__('Categories', 'jkd-core'),
                        'name' => 'option_categories',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the categories meta box', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                    array(
                        'key' => 'field_tags',
                        'label' => esc_html__('Tags', 'jkd-core'),
                        'name' => 'option_tags',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the tags meta box', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                ),
                'location' => array(
                    array(
                        array(
                            'param' => 'post_type',
                            'operator' => '==',
                            'value' => 'post',
                        ),
                    ),
                ),
                'menu_order' => 0,
                'position' => 'side',
                'style' => 'default',
                'label_placement' => 'top',
                'instruction_placement' => 'label',
                'active' => true,
            ));

        endif;

    }

    /**
     *
     */
    public function add_portfolio_settings()
    {

        /* check if exists ACF */
        if (class_exists('ACF')):

            acf_add_local_field_group(array(
                'key' => 'group_portfolio_settings',
                'title' => esc_html__('Portfolio Settings', 'jkd-core'),
                'fields' => array(
                    array(
                        'key' => 'field_portfolio_item_type',
                        'label' => esc_html__('Video', 'jkd-core'),
                        'name' => 'option_portfolio_item_type',
                        'type' => 'button_group',
                        'choices' => array(
                            'default' => esc_html('Default', 'jkd-core'),
                            'gallery' => esc_html('Gallery', 'jkd-core'),
                            'video' => esc_html('Video', 'jkd-core'),
                            'gif' => esc_html('Gif', 'jkd-core'),
                        ),
                        'default_value' => 'default',
                        'layout' => 'horizontal',
                        'return_format' => 'value',
                    ),
                    array(
                        'key' => 'field_portfolio_item_gif_file',
                        'label' => esc_html__('GIF', 'jkd-core'),
                        'name' => 'option_portfolio_item_gif_file',
                        'type' => 'file',
                        'return_format' => 'id',
                        'library' => 'all',
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_portfolio_item_type',
                                    'operator' => '==',
                                    'value' => 'gif',
                                ),
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_portfolio_item_gallery',
                        'label' => esc_html__('Gallery', 'jkd-core'),
                        'name' => 'option_portfolio_item_gallery',
                        'type' => 'gallery',
                        'return_format' => 'id',
                        'preview_size' => 'medium',
                        'insert' => 'append',
                        'library' => 'all',
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_portfolio_item_type',
                                    'operator' => '==',
                                    'value' => 'gallery',
                                ),
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_portfolio_item_video_type',
                        'label' => esc_html__('Video Type', 'jkd-core'),
                        'name' => 'option_portfolio_item_video_type',
                        'type' => 'button_group',
                        'choices' => array(
                            'html' => esc_html('HTML'),
                            'vimeo' => esc_html('Vimeo'),
                            'youtube' => esc_html('Youtube'),
                        ),
                        'default_value' => 'default',
                        'layout' => 'horizontal',
                        'return_format' => 'value',
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_portfolio_item_type',
                                    'operator' => '==',
                                    'value' => 'video',
                                ),
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_portfolio_item_video_file',
                        'label' => esc_html__('HTML Video', 'jkd-core'),
                        'name' => 'option_portfolio_item_video_file',
                        'type' => 'file',
                        'return_format' => 'url',
                        'library' => 'all',
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_portfolio_item_type',
                                    'operator' => '==',
                                    'value' => 'video',
                                ),
                                array(
                                    'field' => 'field_portfolio_item_video_type',
                                    'operator' => '==',
                                    'value' => 'html',
                                ),
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_portfolio_item_video_url',
                        'label' => esc_html__('Video URL', 'jkd-core'),
                        'name' => 'option_portfolio_item_video_url',
                        'type' => 'url',
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_portfolio_item_video_type',
                                    'operator' => '==',
                                    'value' => 'youtube',
                                ),
                                array(
                                    'field' => 'field_portfolio_item_type',
                                    'operator' => '==',
                                    'value' => 'video',
                                ),
                            ),
                            array(
                                array(
                                    'field' => 'field_portfolio_item_video_type',
                                    'operator' => '==',
                                    'value' => 'vimeo',
                                ),
                                array(
                                    'field' => 'field_portfolio_item_type',
                                    'operator' => '==',
                                    'value' => 'video',
                                ),
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_portfolio_item_attributes',
                        'label' => esc_html__('Project Attributes', 'jkd_core'),
                        'name' => 'option_portfolio_item_attributes',
                        'type' => 'repeater',
                        'instructions' => esc_html__('Add some project attributes', 'jkd-core'),
                        'layout' => 'block',
                        'sub_fields' => array(
                            array(
                                'key' => 'attr_title',
                                'label' => esc_html__('Attribute Title', 'jkd-core'),
                                'name' => 'attr_title',
                                'type' => 'text',
                            ),
                            array(
                                'key' => 'attr_value',
                                'label' => esc_html__('Attribute Value', 'jkd-core'),
                                'name' => 'attr_value',
                                'type' => 'text',
                                'tabs' => 'all',
                                'toolbar' => 'full',
                                'media_upload' => 0,
                            ),
                        ),
                    ),
                ),
                'location' => array(
                    array(
                        array(
                            'param' => 'post_type',
                            'operator' => '==',
                            'value' => 'portfolio',
                        ),
                    ),
                ),
                'menu_order' => 0,
                'position' => 'side',
                'style' => 'default',
                'label_placement' => 'top',
                'instruction_placement' => 'label',
                'active' => true,
            ));

            acf_add_local_field_group(array(
                'key' => 'group_meta_portfolio_settings',
                'title' => esc_html__('Meta Settings', 'jkd-core'),
                'fields' => array(
                    array(
                        'key' => 'field_portfolio_author',
                        'label' => esc_html__('Author', 'jkd-core'),
                        'name' => 'option_portfolio_author',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the author meta box', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                    array(
                        'key' => 'field_portfolio_date',
                        'label' => esc_html__('Date', 'jkd-core'),
                        'name' => 'option_portfolio_date',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the date meta box', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                    array(
                        'key' => 'field_portfolio_categories',
                        'label' => esc_html__('Categories', 'jkd-core'),
                        'name' => 'option_portfolio_categories',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the categories meta box', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                    array(
                        'key' => 'field_portfolio_tags',
                        'label' => esc_html__('Tags', 'jkd-core'),
                        'name' => 'option_portfolio_tags',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the tags meta box', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                ),
                'location' => array(
                    array(
                        array(
                            'param' => 'post_type',
                            'operator' => '==',
                            'value' => 'portfolio',
                        ),
                    ),
                ),
                'menu_order' => 0,
                'position' => 'side',
                'style' => 'default',
                'label_placement' => 'top',
                'instruction_placement' => 'label',
                'active' => true,
            ));

        endif;

    }

    /**
     * add footer settings
     */
    public function add_footer_settings()
    {

        /* check if exists ACF */
        if (class_exists('ACF')):

            /* menu item settings group */
            acf_add_local_field_group(array(
                'key' => 'group_footer_settings',
                'title' => __('Footer', 'jkd-core'),
                'location' => array(
                    array(
                        array(
                            'param' => 'post_type',
                            'operator' => '==',
                            'value' => 'all',
                        ),
                    ),
                ),
                'position' => 'side',
                'fields' => array(
                    array(
                        'key' => 'field_after_content_toggle',
                        'label' => esc_html__('After Content Sections', 'jkd-core'),
                        'name' => 'option_after_content_toggle',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the after-content sections', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                    array(
                        'key' => 'field_footer',
                        'label' => esc_html__('Footer', 'jkd-core'),
                        'name' => 'option_footer',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the footer', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                    array(
                        'key' => 'field_cta',
                        'label' => esc_html__('CTA', 'jkd-core'),
                        'name' => 'option_cta',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the CTA', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                ),
            ));

        endif;

    }

    /**
     * add templates settings
     */
    public function add_templates_settings()
    {

        /* check if exists ACF */
        if (class_exists('ACF')):

            $portfolio_categories = get_terms(array(
                'taxonomy' => 'portfolio-categories',
                'hide_empty' => false,
            ));

            $portfolio_tags = get_terms(array(
                'taxonomy' => 'portfolio-tags',
                'hide_empty' => false,
            ));

            $formatted_categories = array();

            $formatted_tags = array();

            if (!empty($portfolio_categories)):

                foreach ($portfolio_categories as $category):

                    $formatted_categories[$category->term_id] = esc_html($category->name);

                endforeach;

            endif;

            if (!empty($portfolio_tags)):

                foreach ($portfolio_tags as $tag):

                    $formatted_tags[$tag->term_id] = esc_html($tag->name);

                endforeach;

            endif;

            /* menu item settings group */
            acf_add_local_field_group(array(
                'key' => 'group_page_template_settings',
                'title' => __('Page Template', 'jkd-core'),
                'position' => 'side',
                'fields' => array(
                    array(
                        'key' => 'field_page_template',
                        'label' => esc_html__('Page Template', 'jkd-core'),
                        'name' => 'option_page_template',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the custom page template', 'jkd-core'),
                        'ui' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                    array(
                        'key' => 'field_page_template_type',
                        'label' => esc_html__('Page Template', 'jkd-core'),
                        'name' => 'option_page_template_type',
                        'type' => 'select',
                        'choices' => array(
                            'blog-two-side' => esc_html__('Blog Two Side', 'jkd-core'),
                            'circular-gallery' => esc_html__('Circular Gallery', 'jkd-core'),
                            'distortion-links' => esc_html__('Distortion Links', 'jkd-core'),
                            'draggable-slider' => esc_html__('Draggable Slider', 'jkd-core'),
                            'events-calendar' => esc_html__('Events Calendar', 'jkd-core'),
                            'horizontal-slider' => esc_html__('Horizontal Slider', 'jkd-core'),
                            'images-gallery' => esc_html__('Images Gallery', 'jkd-core'),
                            'interactive-showcase' => esc_html__('Interactive Showcase', 'jkd-core'),
                            'letters-showcase' => esc_html__('Letters Showcase', 'jkd-core'),
                            'minimal-list' => esc_html__('Minimal List', 'jkd-core'),
                            'organic-slider' => esc_html__('Organic Slider', 'jkd-core'),
                            'products-showcase' => esc_html__('Products Showcase', 'jkd-core'),
                            'products-slider' => esc_html__('Products Slider', 'jkd-core'),
                            'tiles-grid' => esc_html__('Tiles Grid', 'jkd-core'),
                            'titles-slider' => esc_html__('Titles Slider', 'jkd-core'),
                            'webgl-slider' => esc_html__('WebGL Slider', 'jkd-core'),
                            'showcase-carousel' => esc_html__('Showcase Carousel', 'jkd-core'),
                            'showcase-slider' => esc_html__('Showcase Slider', 'jkd-core'),
                            'portfolio-columns' => esc_html__('Portfolio Columns', 'jkd-core'),
                            'reveal-columns' => esc_html__('Reveal Columns', 'jkd-core'),
                            'visual-gallery' => esc_html__('Visual Gallery', 'jkd-core'),
                            'rotated-links' => esc_html__('Rotated Links', 'jkd-core'),
                        ),
                        'default_value' => false,
                        'ui' => 1,
                        'return_format' => 'value',
                        'placeholder' => esc_html__('Page Template (Optional)', 'jkd-core'),
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_page_template',
                                    'operator' => '==',
                                    'value' => '1',
                                ),
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_items_count',
                        'label' => esc_html__('Items Count', 'jkd-core'),
                        'name' => 'option_items_count',
                        'type' => 'range',
                        'default_value' => 12,
                        'min' => 1,
                        'max' => 36,
                        'step' => 1,
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_page_template',
                                    'operator' => '==',
                                    'value' => '1',
                                ),
                            ),
                        ),
                    ),

                    /* portfolio filters */
                    array(
                        'key' => 'field_page_portfolio_filters',
                        'label' => esc_html__('Filters', 'jkd-core'),
                        'name' => 'option_page_portfolio_filters',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the portfolio filters', 'jkd-core'),
                        'ui' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_page_template',
                                    'operator' => '==',
                                    'value' => '1',
                                ),
                                array(
                                    'field' => 'field_page_template_type',
                                    'operator' => '!=',
                                    'value' => 'blog-two-side',
                                ),
                                array(
                                    'field' => 'field_page_template_type',
                                    'operator' => '!=',
                                    'value' => 'events-calendar',
                                ),
                                array(
                                    'field' => 'field_page_template_type',
                                    'operator' => '!=',
                                    'value' => 'images-gallery',
                                ),
                                array(
                                    'field' => 'field_page_template_type',
                                    'operator' => '!=',
                                    'value' => 'products-showcase',
                                ),
                                array(
                                    'field' => 'field_page_template_type',
                                    'operator' => '!=',
                                    'value' => 'products-slider',
                                ),
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_page_portfolio_filters_type',
                        'label' => esc_html__('Filter Type', 'jkd-core'),
                        'name' => 'option_page_portfolio_filters_type',
                        'type' => 'button_group',
                        'choices' => array(
                            'categories' => esc_html__('Categories', 'jkd-core'),
                            'tags' => esc_html__('Tags', 'jkd-core'),
                        ),
                        'default_value' => 'categories',
                        'layout' => 'horizontal',
                        'return_format' => 'value',
                        'conditional_logic' => array(
                            array(
                                'field' => 'field_page_template',
                                'operator' => '==',
                                'value' => '1',
                            ),
                            array(
                                'field' => 'field_page_template_type',
                                'operator' => '!=',
                                'value' => 'blog-two-side',
                            ),
                            array(
                                'field' => 'field_page_template_type',
                                'operator' => '!=',
                                'value' => 'events-calendar',
                            ),
                            array(
                                'field' => 'field_page_template_type',
                                'operator' => '!=',
                                'value' => 'images-gallery',
                            ),
                            array(
                                'field' => 'field_page_template_type',
                                'operator' => '!=',
                                'value' => 'products-showcase',
                            ),
                            array(
                                'field' => 'field_page_template_type',
                                'operator' => '!=',
                                'value' => 'products-slider',
                            ),
                            array(
                                'field' => 'field_page_portfolio_filters',
                                'operator' => '==',
                                'value' => '1',
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_page_portfolio_filter_by_categories',
                        'label' => esc_html__('Filter By Categories', 'jkd-core'),
                        'name' => 'option_page_portfolio_filter_by_categories',
                        'type' => 'select',
                        'choices' => $formatted_categories,
                        'ui' => 1,
                        'return_format' => 'value',
                        'placeholder' => esc_html__('Categories', 'jkd-core'),
                        'conditional_logic' => array(
                            array(
                                'field' => 'field_page_template',
                                'operator' => '==',
                                'value' => '1',
                            ),
                            array(
                                'field' => 'field_page_template_type',
                                'operator' => '!=',
                                'value' => 'blog-two-side',
                            ),
                            array(
                                'field' => 'field_page_template_type',
                                'operator' => '!=',
                                'value' => 'events-calendar',
                            ),
                            array(
                                'field' => 'field_page_template_type',
                                'operator' => '!=',
                                'value' => 'images-gallery',
                            ),
                            array(
                                'field' => 'field_page_template_type',
                                'operator' => '!=',
                                'value' => 'products-showcase',
                            ),
                            array(
                                'field' => 'field_page_template_type',
                                'operator' => '!=',
                                'value' => 'products-slider',
                            ),
                            array(
                                'field' => 'field_page_portfolio_filters',
                                'operator' => '==',
                                'value' => '1',
                            ),
                            array(
                                'field' => 'field_page_portfolio_filters_type',
                                'operator' => '==',
                                'value' => 'categories',
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_page_portfolio_filter_by_tags',
                        'label' => esc_html__('Filter By Tags', 'jkd-core'),
                        'name' => 'option_page_portfolio_filter_by_tags',
                        'type' => 'select',
                        'choices' => $formatted_tags,
                        'ui' => 1,
                        'return_format' => 'value',
                        'placeholder' => esc_html__('Tags', 'jkd-core'),
                        'conditional_logic' => array(
                            array(
                                'field' => 'field_page_template',
                                'operator' => '==',
                                'value' => '1',
                            ),
                            array(
                                'field' => 'field_page_template_type',
                                'operator' => '!=',
                                'value' => 'blog-two-side',
                            ),
                            array(
                                'field' => 'field_page_template_type',
                                'operator' => '!=',
                                'value' => 'events-calendar',
                            ),
                            array(
                                'field' => 'field_page_template_type',
                                'operator' => '!=',
                                'value' => 'images-gallery',
                            ),
                            array(
                                'field' => 'field_page_template_type',
                                'operator' => '!=',
                                'value' => 'products-showcase',
                            ),
                            array(
                                'field' => 'field_page_template_type',
                                'operator' => '!=',
                                'value' => 'products-slider',
                            ),
                            array(
                                'field' => 'field_page_portfolio_filters',
                                'operator' => '==',
                                'value' => '1',
                            ),
                            array(
                                'field' => 'field_page_portfolio_filters_type',
                                'operator' => '==',
                                'value' => 'tags',
                            ),
                        ),
                    ),

                    /* gallery */
                    array(
                        'key' => 'field_gallery_images',
                        'label' => esc_html__('Gallery Images', 'jkd-core'),
                        'name' => 'option_gallery_images',
                        'type' => 'gallery',
                        'instructions' => esc_html__('Upload some gallery images', 'jkd-core'),
                        'return_format' => 'id',
                        'preview_size' => 'thumbnail',
                        'insert' => 'append',
                        'library' => 'all',
                        'min' => 1,
                        'max' => 99,
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_page_template',
                                    'operator' => '==',
                                    'value' => '1',
                                ),
                                array(
                                    'field' => 'field_page_template_type',
                                    'operator' => '==',
                                    'value' => 'images-gallery',
                                ),
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_gallery_layout',
                        'label' => esc_html__('Gallery Layout', 'jkd-core'),
                        'name' => 'option_gallery_layout',
                        'type' => 'button_group',
                        'required' => 0,
                        'choices' => array(
                            'boxed' => esc_html__('Boxed', 'jkd-core'),
                            'full-width' => esc_html__('Full Width', 'jkd-core'),
                        ),
                        'default_value' => 'full-width',
                        'return_format' => 'value',
                        'placeholder' => esc_html__('Gallery Layout', 'jkd-core'),
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_page_template',
                                    'operator' => '==',
                                    'value' => '1',
                                ),
                                array(
                                    'field' => 'field_page_template_type',
                                    'operator' => '==',
                                    'value' => 'images-gallery',
                                ),
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_gallery_grid_type',
                        'label' => esc_html__('Grid Type', 'jkd-core'),
                        'name' => 'option_gallery_grid_type',
                        'type' => 'button_group',
                        'required' => 0,
                        'choices' => array(
                            'fitRows' => esc_html__('FitRows', 'jkd-core'),
                            'masonry' => esc_html__('Masonry', 'jkd-core'),
                        ),
                        'default_value' => 'fitRows',
                        'return_format' => 'value',
                        'placeholder' => esc_html__('Grid Type', 'jkd-core'),
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_page_template',
                                    'operator' => '==',
                                    'value' => '1',
                                ),
                                array(
                                    'field' => 'field_page_template_type',
                                    'operator' => '==',
                                    'value' => 'images-gallery',
                                ),
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_gallery_columns',
                        'label' => esc_html__('Gallery Columns', 'jkd-core'),
                        'name' => 'option_gallery_columns',
                        'type' => 'range',
                        'default_value' => 3,
                        'min' => 1,
                        'max' => 8,
                        'step' => 1,
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_page_template',
                                    'operator' => '==',
                                    'value' => '1',
                                ),
                                array(
                                    'field' => 'field_page_template_type',
                                    'operator' => '==',
                                    'value' => 'images-gallery',
                                ),
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_gallery_offset',
                        'label' => esc_html__('Gallery Offset', 'jkd-core'),
                        'name' => 'option_gallery_offset',
                        'type' => 'range',
                        'default_value' => 15,
                        'min' => 1,
                        'max' => 100,
                        'step' => 1,
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_page_template',
                                    'operator' => '==',
                                    'value' => '1',
                                ),
                                array(
                                    'field' => 'field_page_template_type',
                                    'operator' => '==',
                                    'value' => 'images-gallery',
                                ),
                            ),
                        ),
                    ),
                    array(
                        'key' => 'field_gallery_load_more',
                        'label' => esc_html__('Load More', 'jkd-core'),
                        'name' => 'option_gallery_load_more',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the load more', 'jkd-core'),
                        'required' => 0,
                        'default_value' => 1,
                        'ui' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_page_template',
                                    'operator' => '==',
                                    'value' => '1',
                                ),
                                array(
                                    'field' => 'field_page_template_type',
                                    'operator' => '==',
                                    'value' => 'images-gallery',
                                ),
                            ),
                        ),
                    ),

                    /* showcase_slider */
                    array(
                        'key' => 'field_showcase_background',
                        'label' => esc_html__('Showcase Background', 'jkd-core'),
                        'name' => 'option_showcase_background',
                        'type' => 'image',
                        'return_format' => 'id',
                        'preview_size' => 'medium',
                        'conditional_logic' => array(
                            array(
                                array(
                                    'field' => 'field_page_template',
                                    'operator' => '==',
                                    'value' => '1',
                                ),
                                array(
                                    'field' => 'field_page_template_type',
                                    'operator' => '==',
                                    'value' => 'showcase-slider',
                                ),
                            ),
                        ),
                    ),

                ),
                'location' => array(
                    array(
                        array(
                            'param' => 'post_type',
                            'operator' => '==',
                            'value' => 'page',
                        ),
                    ),
                ),
            ));

        endif;

    }

    /**
     *
     */
    public function add_global_settings()
    {

        /* check if exists ACF */
        if (class_exists('ACF')):

            /* menu item settings group */
            acf_add_local_field_group(array(
                'key' => 'group_global_settings',
                'title' => __('Global Settings', 'jkd-core'),
                'location' => array(
                    array(
                        array(
                            'param' => 'post_type',
                            'operator' => '==',
                            'value' => 'all',
                        ),
                    ),
                ),
                'position' => 'side',
                'fields' => array(
                    array(
                        'key' => 'field_search_form_toggle',
                        'label' => esc_html__('Search Form', 'jkd-core'),
                        'name' => 'option_search_form_toggle',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the search form', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                    array(
                        'key' => 'field_page_progressbar_toggle',
                        'label' => esc_html__('Page Progressbar', 'jkd-core'),
                        'name' => 'option_page_progressbar_toggle',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the page progressbar', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                    array(
                        'key' => 'field_fixed_social_list_toggle',
                        'label' => esc_html__('Fixed Social List', 'jkd-core'),
                        'name' => 'option_fixed_social_list_toggle',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the fixed social list', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                    array(
                        'key' => 'field_scroll_top_button_toggle',
                        'label' => esc_html__('Scroll Top Button', 'jkd-core'),
                        'name' => 'option_scroll_top_button_toggle',
                        'type' => 'true_false',
                        'instructions' => esc_html__('If true - will be enabled the scroll top button', 'jkd-core'),
                        'ui' => 1,
                        'default_value' => 1,
                        'ui_on_text' => esc_html__('Enable', 'jkd-core'),
                        'ui_off_text' => esc_html__('Disable', 'jkd-core'),
                    ),
                ),
            ));

        endif;

    }

}
