<?php defined('ABSPATH') || exit;
/*
 *
 */

use Elementor\Plugin;

/**
 * Class JKD_Helper
 */
class JKD_Helper extends JKD_Core
{

    /**
     * @param $content
     *
     * @return string
     */
    public static function get_reading_time($content = false)
    {

        if ($content):

            $word_count = str_word_count(strip_tags($content));

            $readingtime = ceil($word_count / 50);

            if ($readingtime == 1) :

                $timer = esc_html__(' minute', 'jkd-core');

            else :

                $timer = esc_html__(' minutes', 'jkd-core');

            endif;

            $totalreadingtime = $readingtime . $timer;

            return $totalreadingtime;

        else:

            return false;

        endif;

    }

    /**
     * @param $option
     * @param bool $default
     *
     * @return mixed
     */
    public static function get_theme_mod($option, $default = false)
    {

        return get_theme_mod($option, $default);

    }

    /**
     * Get Elementor templates
     *
     * @param string $type type of templates
     *
     * @return array of Elementor templates
     * @since 1.0.0
     * @access public
     * @static
     *
     */
    public static function get_elementor_templates($type = 'section')
    {

        $templates = Plugin::$instance->templates_manager->get_source('local')->get_items([
            'type' => $type,
        ]);

        if ($templates):

            return $templates;

        else:

            return false;

        endif;

    }

    /**
     * @return array
     */
    public static function get_cf7()
    {

        $options = array();

        if (function_exists('wpcf7')) :

            $wpcf7_form_list = get_posts(array(
                'post_type' => 'wpcf7_contact_form',
                'posts_per_page' => 999,
            ));

            $options[0] = esc_html__('Select a Contact Form', 'jkd-core');

            if (!empty($wpcf7_form_list) && !is_wp_error($wpcf7_form_list)) :

                foreach ($wpcf7_form_list as $post) :

                    $options[$post->ID] = $post->post_title;

                endforeach;

            else :

                $options[0] = esc_html__('Create a Form First', 'jkd-core');

            endif;

        endif;

        return $options;

    }

    /**
     * @return mixed
     */
    public static function get_ip_address()
    {

        $headers = (function_exists('apache_request_headers')) ? apache_request_headers() : $_SERVER;

        if (!empty($headers)):

            if (array_key_exists('X-Forwarded-For', $headers) && filter_var($headers['X-Forwarded-For'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV4)) :

                return $headers['X-Forwarded-For'];

            endif;

            if (array_key_exists('HTTP_X_FORWARDED_FOR', $headers) && filter_var($headers['HTTP_X_FORWARDED_FOR'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV4)) :

                return $headers['HTTP_X_FORWARDED_FOR'];

            endif;

            return $_SERVER['REMOTE_ADDR'];

        endif;

    }

    /**
     *
     */
    public static function the_comments()
    {

        comments_template();

    }

    /**
     * @param $param
     */
    public static function the_option($param, $default = false)
    {

        if (function_exists('the_field')) :

            return the_field($param, 'option');

        else:

            return $default;

        endif;

    }

    /**
     * @param $param
     *
     * @return mixed
     */
    public static function get_option($param, $default = false)
    {

        if (function_exists('get_field')) :

            return get_field($param, 'option');

        else:

            return $default;

        endif;

    }

    /**
     * @param $param
     * @param null $id
     */
    public static function the_field($param, $id = null)
    {

        if ($id == null) :

            $id = get_the_ID();

        endif;

        if (function_exists('the_field')) :

            return the_field($param, $id);

        endif;

    }

    /**
     * @param $param
     * @param null $id
     *
     * @return mixed
     */
    public static function get_field($param, $id = null, $default = false)
    {

        if ($id == null) :

            $id = get_the_ID();

        endif;

        if (function_exists('get_field')) :

            return get_field($param, $id);

        else:

            return $default;

        endif;

    }

    /**
     * @param $param
     */
    public static function the_sub_field($param, $default = false)
    {

        if (function_exists('the_sub_field')) :

            return the_sub_field($param);

        else:

            return $default;

        endif;

    }

    /**
     * @param $param
     *
     * @return bool
     */
    public static function get_sub_field($param, $default = false)
    {

        if (function_exists('get_sub_field')) :

            return get_sub_field($param);

        else:

            return $default;

        endif;

    }

    /**
     * @param $path
     *
     * @return string
     */
    public static function get_plugin_folder_path($path)
    {

        return plugin_dir_url(dirname(__FILE__)) . $path;

    }

    /**
     * @return false|int|string
     */
    public static function get_last_updated_date()
    {

        $u_time = get_the_time('U');

        $u_modified_time = get_the_modified_time('U');

        if ($u_modified_time >= $u_time + 86400) :

            $updated_date = get_the_modified_time(get_option('date_format'));

            return $updated_date;

        else:

            return false;

        endif;

    }

    /**
     * @param $post_id
     */
    public static function set_post_view($post_id)
    {

        $ip = JKD_Helper::get_ip_address();

        $current_viewer = get_transient('post_view_' . $post_id . '_' . $ip);

        if (!$current_viewer):

            set_transient('post_view_' . $post_id . '_' . $ip, true, 60 * 60 * 24);

            $old_value = get_option('post_views_' . $post_id) ? get_option('post_views_' . $post_id) : 0;

            $old_value++;

            update_option('post_views_' . $post_id, $old_value);

        endif;

    }

    /**
     * @param $post_id
     *
     * @return false|int|mixed|void
     */
    public static function get_post_views($post_id)
    {

        return get_option('post_views_' . $post_id) ? get_option('post_views_' . $post_id) : 0;

    }

    /**
     * @param $post_id
     *
     * @return false|int|mixed|void
     */
    public static function get_post_likes($post_id)
    {

        return get_option('post_likes_' . $post_id) ? get_option('post_likes_' . $post_id) : 0;

    }

    /**
     * @return array
     */
    public static function get_remix_social_icons()
    {

        return array(
            'ri-behance-line' => __('Behance', 'jkd-core'),
            'ri-amazon-line' => __('Amazon', 'jkd-core'),
            'ri-discord-line' => __('Discord', 'jkd-core'),
            'ri-dribbble-line' => __('Dribbble', 'jkd-core'),
            'ri-facebook-line' => __('Facebook', 'jkd-core'),
            'ri-github-line' => __('Github', 'jkd-core'),
            'ri-gitlab-line' => __('Gitlab', 'jkd-core'),
            'ri-instagram-line' => __('Instagram', 'jkd-core'),
            'ri-linkedin-box-line' => __('Linkedin', 'jkd-core'),
            'ri-mastercard-line' => __('Mastercard', 'jkd-core'),
            'ri-medium-line' => __('Medium', 'jkd-core'),
            'ri-patreon-line' => __('Patreon', 'jkd-core'),
            'ri-paypal-line' => __('Paypal', 'jkd-core'),
            'ri-pinterest-line' => __('Pinterest', 'jkd-core'),
            'ri-reddit-line' => __('Reddit', 'jkd-core'),
            'ri-slack-line' => __('Slack', 'jkd-core'),
            'ri-skype-line' => __('Skype', 'jkd-core'),
            'ri-tumblr-line' => __('Tumblr', 'jkd-core'),
            'ri-twitch-line' => __('Twitch', 'jkd-core'),
            'ri-twitter-line' => __('Twitter', 'jkd-core'),
            'ri-vimeo-line' => __('Vimeo', 'jkd-core'),
            'ri-unsplash-line' => __('Unsplash', 'jkd-core'),
            'ri-visa-line' => __('Visa', 'jkd-core'),
            'ri-xing-line' => __('Xing', 'jkd-core'),
            'ri-mail-open-line' => __('Email', 'jkd-core'),
            'ri-youtube-line' => __('Youtube', 'jkd-core'),
        );

    }

    /**
     * @return array
     */
    public static function get_remix_common_icons()
    {

        return array(
            'ri-star-line' => __('Star', 'jkd-core'),
            'ri-mail-line' => __('Mail', 'jkd-core'),
            'ri-mail-open-line' => __('Mail Open', 'jkd-core'),
            'ri-mail-send-line' => __('Mail Send', 'jkd-core'),
            'ri-mail-unread-line' => __('Mail Unread', 'jkd-core'),
            'ri-home-line' => __('Home Line', 'jkd-core'),
            'ri-inbox-line' => __('Inbox', 'jkd-core'),
            'ri-send-plane-line' => __('Paper Plane', 'jkd-core'),
            'ri-message-2-line' => __('Chat', 'jkd-core'),
            'ri-rss-line' => __('RSS', 'jkd-core'),
            'ri-bookmark-line' => __('Bookmark', 'jkd-core'),
            'ri-global-line' => __('Global 1', 'jkd-core'),
            'ri-earth-line' => __('Global 2', 'jkd-core'),
            'ri-bill-line' => __('Bill', 'jkd-core'),
            'ri-heart-line' => __('Heart', 'jkd-core'),
        );

    }

}
