<?php defined('ABSPATH') || exit;
/*
 *
 */

/**
 * Class JKD_Navigation
 */
class JKD_Navigation extends JKD_Core
{

    /**
     * JKD_Navigation constructor.
     */
    public function __construct()
    {

        $this->init();

    }

    /**
     *
     */
    public function init()
    {

        add_action('wp_ajax_nopriv_jkd_ajax_search_form', [$this, 'ajax_search_form']);
        add_action('wp_ajax_jkd_ajax_search_form', [$this, 'ajax_search_form']);

        add_action('wp_ajax_nopriv_jkd_cart_content', [$this, 'cart_content_render']);
        add_action('wp_ajax_jkd_cart_content', [$this, 'cart_content_render']);

        add_action('wp_ajax_nopriv_jkd_shopping_cart_remove_item', [$this, 'shopping_cart_remove_item']);
        add_action('wp_ajax_jkd_shopping_cart_remove_item', [$this, 'shopping_cart_remove_item']);

        add_action('wp_ajax_nopriv_jkd_shopping_cart_change_quantity', [$this, 'shopping_cart_change_quantity']);
        add_action('wp_ajax_jkd_shopping_cart_change_quantity', [$this, 'shopping_cart_change_quantity']);

        add_action('wp_ajax_nopriv_jkd_switch_reg', [$this, 'switch_reg']);
        add_action('wp_ajax_jkd_switch_reg', [$this, 'switch_reg']);

        add_action('wp_ajax_nopriv_jkd_reg', [$this, 'register_handler']);
        add_action('wp_ajax_jkd_reg', [$this, 'register_handler']);

        add_action('wp_ajax_nopriv_jkd_switch_login', [$this, 'switch_login']);
        add_action('wp_ajax_jkd_switch_login', [$this, 'switch_login']);

        add_action('wp_ajax_nopriv_jkd_avoid_newsletter_modal', [$this, 'avoid_newsletter_modal']);
        add_action('wp_ajax_jkd_avoid_newsletter_modal', [$this, 'avoid_newsletter_modal']);

        add_action('wp_ajax_nopriv_jkd_color_scheme_switcher', [$this, 'color_scheme_switcher']);
        add_action('wp_ajax_jkd_color_scheme_switcher', [$this, 'color_scheme_switcher']);

        add_action('login_form_middle', [$this, 'add_lost_password_link']);

    }

    /**
     * @return void
     */
    public function register_handler()
    {

        $info = array();

        $info['user_nicename'] = $info['nickname'] = $info['display_name'] = $info['first_name'] = $info['user_login'] = sanitize_user($_POST['username']);

        $info['user_pass'] = sanitize_text_field($_POST['password']);

        $info['user_email'] = sanitize_email($_POST['email']);

        $info['role'] = 'customer';

        $user_register = wp_insert_user($info);

        if (is_wp_error($user_register)) :

            $error = $user_register->get_error_codes();

            if (in_array('empty_user_login', $error)):

                $string = json_encode(array('loggedin' => false, 'redirecturl' => home_url(), 'message' => __($user_register->get_error_message('empty_user_login'))));

                $string = str_replace('\\', '', $string);

            elseif (in_array('existing_user_login', $error)):

                $string = json_encode(array('loggedin' => false, 'redirecturl' => home_url(), 'message' => __('This username is already registered.', 'jkd-core')));

                $string = str_replace('\\', '', $string);

            elseif (in_array('existing_user_email', $error)):

                $string = json_encode(array('loggedin' => false, 'redirecturl' => home_url(), 'message' => __('This email address is already registered.', 'jkd-core')));

                $string = str_replace('\\', '', $string);

            endif;

            echo $string;

        else :

            wp_signon(array(
                'user_login' => $info['nickname'],
                'user_password' => $info['user_pass'],
            ), false);

            if (class_exists('WooCommerce')):

                $myaccount_page = get_option('woocommerce_myaccount_page_id');

                $myaccount_page_url = get_permalink($myaccount_page);

            else:

                $myaccount_page_url = esc_url(get_home_url());

            endif;

            echo json_encode(array('url' => esc_url($myaccount_page_url)));

        endif;

        die();

    }

    /**
     *
     */
    public function ajax_search_form()
    {

        wp_reset_postdata();

        $query = trim($_POST['query']);

        $search_types = $_POST['search_types'];

        if (!empty($search_types) && !empty($query)):

            $search_types = str_replace("\\", "", $search_types);

            $search_types = json_decode($search_types);

            if (in_array('posts', $search_types)):

                $posts_args = array(
                    's' => $query,
                    'order' => 'DESC',
                    'post_type' => 'post',
                    'ignore_sticky_posts' => 1,
                    'posts_per_page' => -1
                );

                $posts_query = new WP_Query($posts_args);

                if ($posts_query->have_posts()) :

                    ?>

                    <div class="results-inner posts-results">

                        <div class="overflow-wrapper">

                            <h6 class="inner-results-title animate-item">

                                <?php echo esc_html__('Posts', 'jkd-core'); ?>

                            </h6>

                        </div>

                        <div class="posts-list items-list">

                            <?php

                            while ($posts_query->have_posts()) : $posts_query->the_post();

                                $title = get_the_title();

                                $date = get_the_date();

                                $category = get_the_category();

                                ?>

                                <div class="overflow-wrapper">

                                    <article <?php post_class('post-article list-item animate-item'); ?>>

                                        <div class="post-inner">

                                            <?php if (has_post_thumbnail()): ?>

                                                <a class="post-header item-header" href="<?php the_permalink(); ?>">

                                                    <?php

                                                    $image_id = get_post_thumbnail_id(get_the_ID());

                                                    echo JKD_Theme::render_image($image_id,
                                                        'thumbnail');

                                                    ?>

                                                </a>

                                            <?php endif; ?>

                                            <div class="post-body item-body">

                                                <a class="category-name"
                                                   href="<?php echo esc_url(get_category_link($category[0]->term_id)); ?>">

                                                    <?php echo esc_html($category[0]->name); ?>

                                                </a>

                                                <h6 class="item-title post-title">

                                                    <a href="<?php the_permalink(); ?>" class="multiline-hover">

                                                        <?php echo esc_html(wp_trim_words($title, 6, '...')); ?>

                                                    </a>

                                                </h6>

                                                <p class="date">

                                                    <?php echo esc_html($date); ?>

                                                </p>

                                            </div>

                                        </div>

                                    </article>

                                </div>

                            <?php

                            endwhile;

                            ?>

                        </div>

                    </div>

                <?php

                endif;

            endif;

            wp_reset_postdata();

            if (in_array('pages', $search_types)):

                $pages_args = array(
                    's' => $query,
                    'order' => 'DESC',
                    'post_type' => 'page',
                    'posts_per_page' => -1
                );

                $pages_query = new WP_Query($pages_args);

                if ($pages_query->have_posts()) :

                    ?>

                    <div class="results-inner pages-results">

                        <h6 class="inner-results-title animate-item">

                            <?php echo esc_html__('Pages', 'jkd-core'); ?>

                        </h6>

                        <div class="pages-list items-list">

                            <?php

                            while ($pages_query->have_posts()) : $pages_query->the_post();

                                $title = get_the_title();

                                ?>

                                <div class="overflow-wrapper">

                                    <article <?php post_class('page-article list-item animate-item'); ?>>

                                        <div class="page-inner">

                                            <h6 class="item-title page-title">

                                                <a href="<?php the_permalink(); ?>" class="multiline-hover">

                                                    <?php echo esc_html(wp_trim_words($title, 10, '...')); ?>

                                                </a>

                                            </h6>

                                        </div>

                                    </article>

                                </div>

                            <?php

                            endwhile;

                            ?>

                        </div>

                    </div>

                <?php

                endif;

            endif;

            wp_reset_postdata();

            if (in_array('portfolio', $search_types)):

                $portfolio_args = array(
                    's' => $query,
                    'order' => 'DESC',
                    'post_type' => 'portfolio',
                    'ignore_sticky_posts' => 1,
                    'posts_per_page' => -1
                );

                $portfolio_query = new WP_Query($portfolio_args);

                if ($portfolio_query->have_posts()) :

                    ?>

                    <div class="results-inner portfolio-results">

                        <div class="overflow-wrapper">

                            <h6 class="inner-results-title animate-item">

                                <?php echo esc_html__('Portfolio', 'jkd-core'); ?>

                            </h6>

                        </div>

                        <div class="portfolio-list items-list">

                            <?php

                            while ($portfolio_query->have_posts()) : $portfolio_query->the_post();

                                $title = get_the_title();

                                $date = get_the_date();

                                $category = get_the_terms(get_the_ID(), 'portfolio-categories');

                                ?>

                                <div class="overflow-wrapper">

                                    <article <?php post_class('portfolio-article list-item animate-item'); ?>>

                                        <div class="portfolio-inner">

                                            <?php if (has_post_thumbnail()): ?>

                                                <a class="portfolio-header item-header"
                                                   href="<?php the_permalink(); ?>">

                                                    <?php

                                                    $image_id = get_post_thumbnail_id(get_the_ID());

                                                    echo JKD_Theme::render_image($image_id,
                                                        'thumbnail');

                                                    ?>

                                                </a>

                                            <?php endif; ?>

                                            <div class="portfolio-body item-body">

                                                <a class="category-name"
                                                   href="<?php echo esc_url(get_category_link($category[0]->term_id)); ?>">

                                                    <?php echo esc_html($category[0]->name); ?>

                                                </a>

                                                <h6 class="item-title portfolio-title">

                                                    <a href="<?php the_permalink(); ?>" class="multiline-hover">

                                                        <?php echo esc_html(wp_trim_words($title, 6, '...')); ?>

                                                    </a>

                                                </h6>

                                                <p class="date">

                                                    <?php echo esc_html($date); ?>

                                                </p>

                                            </div>

                                        </div>

                                    </article>

                                </div>

                            <?php

                            endwhile;

                            ?>

                        </div>

                    </div>

                <?php

                endif;

            endif;

            wp_reset_postdata();

            if (in_array('products', $search_types)):

                $products_args = array(
                    's' => $query,
                    'order' => 'DESC',
                    'post_type' => 'product',
                    'ignore_sticky_posts' => 1,
                    'posts_per_page' => -1
                );

                $products_query = new WP_Query($products_args);

                if ($products_query->have_posts()) :

                    ?>

                    <div class="results-inner products-results">

                        <div class="overflow-wrapper">

                            <h6 class="inner-results-title animate-item">

                                <?php echo esc_html__('Products', 'jkd-core'); ?>

                            </h6>

                        </div>

                        <div class="products-list items-list">

                            <?php

                            while ($products_query->have_posts()) : $products_query->the_post();

                                $title = get_the_title();

                                $date = get_the_date();

                                $category = get_the_terms(get_the_ID(), 'product_cat');

                                $product = wc_get_product(get_the_ID());

                                ?>

                                <div class="overflow-wrapper">

                                    <article <?php post_class('product-article list-item animate-item'); ?>>

                                        <div class="product-inner">

                                            <a class="product-header item-header" href="<?php the_permalink(); ?>">

                                                <?php

                                                $image_id = get_post_thumbnail_id(get_the_ID());

                                                echo JKD_Theme::render_image($image_id,
                                                    'thumbnail');

                                                ?>

                                            </a>

                                            <div class="product-body item-body">

                                                <a class="category-name"
                                                   href="<?php echo esc_url(get_category_link($category[0]->term_id)); ?>">

                                                    <?php echo esc_html($category[0]->name); ?>

                                                </a>

                                                <h6 class="item-title product-title">

                                                    <a href="<?php the_permalink(); ?>" class="multiline-hover">

                                                        <?php echo esc_html(wp_trim_words($title, 6, '...')); ?>

                                                    </a>

                                                </h6>

                                                <p class="product-price">

                                                    <?php echo $product->get_price_html(); ?>

                                                </p>

                                            </div>

                                        </div>

                                    </article>

                                </div>

                            <?php

                            endwhile;

                            ?>

                        </div>

                    </div>

                <?php

                endif;

            endif;

            wp_reset_postdata();

            if (in_array('events', $search_types)):

                $events_args = array(
                    's' => $query,
                    'order' => 'DESC',
                    'post_type' => 'tribe_events',
                    'ignore_sticky_posts' => 1,
                    'posts_per_page' => -1
                );

                $events_query = new WP_Query($events_args);

                if ($events_query->have_posts()) :

                    ?>

                    <div class="results-inner events-results">

                        <div class="overflow-wrapper">

                            <h6 class="inner-results-title animate-item">

                                <?php echo esc_html__('Events', 'jkd-core'); ?>

                            </h6>

                        </div>

                        <div class="events-list items-list">

                            <?php

                            while ($events_query->have_posts()) : $events_query->the_post();

                                $title = get_the_title();

                                $id = get_the_ID();

                                $full_address = tribe_get_full_address($id);

                                $start_date = tribe_get_start_date(null);

                                $end_date = tribe_get_end_date(null, false);

                                $orginizer = tribe_get_organizer($id);

                                $cats = get_the_terms($id, 'tribe_events_cat');

                                ?>

                                <div class="overflow-wrapper">

                                    <article <?php post_class('event-article list-item animate-item'); ?>>

                                        <div class="event-inner">

                                            <a class="event-header item-header" href="<?php the_permalink(); ?>">

                                                <?php

                                                $image_id = get_post_thumbnail_id(get_the_ID());

                                                echo JKD_Theme::render_image($image_id,
                                                    'thumbnail');

                                                ?>

                                            </a>

                                            <div class="event-body item-body">

                                                <a class="category-name"
                                                   href="<?php echo esc_url(get_term_link($cats[0]->term_id)); ?>">

                                                    <?php echo esc_html($cats[0]->name); ?>

                                                </a>

                                                <h6 class="item-title event-title">

                                                    <a href="<?php the_permalink(); ?>" class="multiline-hover">

                                                        <?php echo esc_html(wp_trim_words($title, 6, '...')); ?>

                                                    </a>

                                                </h6>

                                                <p class="event-date">

                                                    <?php echo esc_html($start_date); ?>

                                                </p>

                                            </div>

                                        </div>

                                    </article>

                                </div>

                            <?php

                            endwhile;

                            ?>

                        </div>

                    </div>

                <?php

                endif;

            endif;

            wp_reset_postdata();

        endif;

        die();

    }

    /**
     *
     */
    public function cart_content_render()
    {

        $cart_style = get_theme_mod('nav-cart-style', 'sub-menu');

        if ($cart_style === 'sub-menu'):

            JKD_Core::template('shop/cart/cart-sub-menu-content');

        elseif ($cart_style === 'panel'):

            JKD_Core::template('shop/cart/cart-panel-content');

        endif;

        die();

    }

    /**
     *
     */
    public function shopping_cart_remove_item()
    {

        $id = (int)$_POST['id'];

        foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) :

            if ($cart_item['product_id'] === $id || $cart_item['variation_id'] === $id) :

                WC()->cart->remove_cart_item($cart_item_key);

            endif;

        endforeach;

        $subtotals = array(
            'count' => WC()->cart->cart_contents_count,
            'totals' => WC()->cart->get_cart_total(),
            'next_item' => false
        );

        if (!empty($_POST['auto-adding']) && $_POST['auto-adding'] === 'yes'):

            $items = WC()->cart->get_cart();

            if (!empty($items) && count($items) > 2):

                ob_start();

                $items = array_values($items);

                $product_id = $items[2]['product_id'];

                $product = wc_get_product($product_id);

                $title = $product->get_title();

                $quantity = $items[2]['quantity'];

                $image_id = get_post_thumbnail_id($product_id);

                ?>

                <article class="product product-article new-item"
                         data-product-id="<?php echo esc_attr($product_id); ?>">

                    <div class="product-inner">

                        <?php if (!empty($image_id)): ?>

                            <a class="product-header" href="<?php echo esc_url($product->get_permalink()); ?>">

                                <?php

                                echo JKD_Theme::render_image($image_id,
                                    'thumbnail');

                                ?>

                            </a>

                        <?php endif; ?>

                        <div class="product-body">

                            <h6 class="product-title">

                                <a href="<?php echo esc_url($product->get_permalink()); ?>"
                                   class="title-link multiline-hover">

                                    <?php echo esc_html(wp_trim_words($title, 6, '...')); ?>

                                </a>

                            </h6>

                            <?php if (!empty($product->get_price_html())): ?>

                                <p class="product-price">

                                    <?php echo $product->get_price_html(); ?>

                                </p>

                            <?php endif; ?>

                            <div class="quantity">

                                <button class="decrease">

                                    <i class="ri-subtract-line"></i>

                                </button>

                                <input type="number" class="quantity-input" min="1"
                                       value="<?php echo esc_attr($quantity); ?>">

                                <button class="increase">

                                    <i class="ri-add-line"></i>

                                </button>

                            </div>

                            <div class="product-remote-button">

                                <i class="ri-close-line"></i>

                            </div>

                        </div>

                    </div>

                </article>

                <?php

                $subtotals['next_item'] = ob_get_clean();

            endif;

        endif;

        echo json_encode($subtotals, JSON_UNESCAPED_SLASHES);

        die();

    }

    /**
     *
     */
    public function shopping_cart_change_quantity()
    {

        $id = (int)$_POST['id'];

        $type = $_POST['type'];

        $old_value = (int)$_POST['old'];

        foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) :

            if ($cart_item['product_id'] === $id) :

                if ($type === 'decrease'):

                    WC()->cart->set_quantity($cart_item_key, $old_value - 1);

                elseif ($type === 'increase'):

                    WC()->cart->set_quantity($cart_item_key, $old_value + 1);

                endif;

            endif;

        endforeach;

        $subtotals = array(
            'count' => WC()->cart->cart_contents_count,
            'totals' => WC()->cart->get_cart_total(),
        );

        echo json_encode($subtotals);

        die();

    }

    /**
     *
     */
    public function color_scheme_switcher()
    {

        $scheme = $_POST['scheme'];

        $ip = JKD_Helper::get_ip_address();

        if ($scheme === 'dark'):

            set_transient('color_scheme_for_' . $ip, 'dark', 60 * 60 * 24);

        elseif ($scheme === 'default'):

            set_transient('color_scheme_for_' . $ip, 'default', 24 * HOUR_IN_SECONDS);

        endif;

        die();

    }

    /**
     *
     */
    public function avoid_newsletter_modal()
    {

        $active = $_POST['active'];

        $ip = JKD_Helper::get_ip_address();

        if ($active === 'active'):

            set_transient('avoid_newsletter_modal_for_' . $ip, 1, 60 * 60 * 24);

        elseif ($active === 'not-active'):

            delete_transient('avoid_newsletter_modal_for_' . $ip);

        endif;

        die();

    }

    /**
     *
     */
    public function switch_login()
    {

        ?>

        <div class="form-wrapper">

            <h4 class="form-title">

                <?php echo esc_html__('Login', 'jkd-core'); ?>

            </h4>

            <?php

            wp_login_form(array(
                'echo' => true,
                'redirect' => esc_url(home_url()),
                'form_id' => 'loginform',
                'label_username' => __('Username or email address *', 'jkd-core'),
                'label_password' => __('Password *', 'jkd-core'),
                'label_remember' => __('Remember Me', 'jkd-core'),
                'label_log_in' => __('Log In', 'jkd-core'),
                'id_username' => 'user_login',
                'id_password' => 'user_pass',
                'id_remember' => 'rememberme',
                'id_submit' => 'wp-submit',
                'remember' => true,
                'value_username' => NULL,
                'value_remember' => false
            ));

            ?>

        </div>

        <div class="auth-redirect-wrapper">

            <p class="info-message">

                <?php echo esc_html__('Don’t have an account?', 'jkd-core'); ?>

            </p>

            <button class="auth-switcher">

                <?php echo esc_html__('Register', 'jkd-core'); ?>

            </button>

        </div>

        <?php

        die();

    }

    /**
     *
     */
    public function switch_reg()
    {

        ?>

        <h4 class="form-title">

            <?php echo esc_html__('Create an account', 'jkd-core'); ?>

        </h4>

        <form class="registration-form">

            <input type="text" name="username" placeholder="<?php echo esc_attr__('Username *', 'jkd-core'); ?>"
                   class="jkd-input" required>

            <input type="email" name="email" placeholder="<?php echo esc_attr__('Email *', 'jkd-core'); ?>"
                   class="jkd-input" required>

            <input type="password" name="password" placeholder="<?php echo esc_attr__('Password *', 'jkd-core'); ?>"
                   class="jkd-input"
                   required>

            <input type="password" name="repeat-password"
                   placeholder="<?php echo esc_attr__('Repeat Password *', 'jkd-core'); ?>" class="jkd-input" required>

            <button class="jkd-button default-style animation-fade" type="submit">

                <?php echo esc_html__('Register', 'jkd-core'); ?>

            </button>

            <div class="reg-alert">

            </div>

        </form>

        <div class="auth-redirect-wrapper">

            <p class="info-message">

                <?php echo esc_html__('Already have an account?', 'jkd-core'); ?>

            </p>

            <button class="auth-switcher">

                <?php echo esc_html__('Login', 'jkd-core'); ?>

            </button>

        </div>

        <?php

        die();

    }

    /**
     * @return string
     */
    public function add_lost_password_link()
    {

        return '<p class="login-lost"><a href="' . wp_lostpassword_url() . '">' . esc_html__('Lost Password?', 'jkd-core') . '</a></p>';

    }

}
