<?php defined('ABSPATH') || exit;
/*
 *
 */

/**
 * Class JKD_Portfolio
 */
class JKD_Portfolio extends JKD_Core
{

    /**
     * JKD_Portfolio constructor.
     */
    public function __construct()
    {

        /* init portfolio */
        $this->init();

        /* register portfolio categories ajax handler */
        add_action('wp_ajax_nopriv_jkd_ajax_portfolio_categories', [$this, 'ajax_categories']);
        add_action('wp_ajax_jkd_ajax_portfolio_categories', [$this, 'ajax_categories']);

        /* register load more ajax handler */
        add_action('wp_ajax_nopriv_jkd_ajax_portfolio_load_more', [$this, 'ajax_grid_load_more']);
        add_action('wp_ajax_jkd_ajax_portfolio_load_more', [$this, 'ajax_grid_load_more']);

        /* register load more slider ajax handler */
        add_action('wp_ajax_nopriv_jkd_ajax_webgl_slider_load_more', [$this, 'ajax_webgl_slider_load_more']);
        add_action('wp_ajax_jkd_ajax_webgl_slider_load_more', [$this, 'ajax_webgl_slider_load_more']);

    }

    /**
     * init
     */
    public function init()
    {

        $portfolio_slug = get_theme_mod('portfolio-custom-slug', 'portfolio');

        /* register portfolio tags taxonomy */
        register_taxonomy('portfolio-tags', array('portfolio'), array(
            'hierarchical' => false,
            'labels' => array(
                'name' => esc_html__('Tags', 'jkd-core'),
                'singular_name' => esc_html__('Tag', 'jkd-core'),
                'search_items' => esc_html__('Search Tags', 'jkd-core'),
                'all_items' => esc_html__('All Tags', 'jkd-core'),
                'parent_item' => esc_html__('Parent Tag', 'jkd-core'),
                'parent_item_colon' => esc_html__('Parent Tag:', 'jkd-core'),
                'edit_item' => esc_html__('Edit Tag', 'jkd-core'),
                'update_item' => esc_html__('Update Tag', 'jkd-core'),
                'add_new_item' => esc_html__('Add New Tag', 'jkd-core'),
                'new_item_name' => esc_html__('New Tag Name', 'jkd-core'),
                'menu_name' => esc_html__('Tags', 'jkd-core'),
            ),
            'show_in_rest' => true,
            'show_ui' => true,
            'show_admin_column' => true,
            'query_let' => true,
            'has_archive' => true,
            'rewrite' => array('slug' => $portfolio_slug . '/tags'),
        ));

        /* register portfolio categories taxonomy */
        register_taxonomy('portfolio-categories', array('portfolio'), array(
            'hierarchical' => true,
            'labels' => array(
                'name' => esc_html__('Categories', 'jkd-core'),
                'singular_name' => esc_html__('Category', 'jkd-core'),
                'search_items' => esc_html__('Search Categories', 'jkd-core'),
                'all_items' => esc_html__('All Categories', 'jkd-core'),
                'parent_item' => esc_html__('Parent Category', 'jkd-core'),
                'parent_item_colon' => esc_html__('Parent Category:', 'jkd-core'),
                'edit_item' => esc_html__('Edit Category', 'jkd-core'),
                'update_item' => esc_html__('Update Category', 'jkd-core'),
                'add_new_item' => esc_html__('Add New Category', 'jkd-core'),
                'new_item_name' => esc_html__('New Category Name', 'jkd-core'),
                'menu_name' => esc_html__('Categories', 'jkd-core'),
            ),
            'show_in_rest' => true,
            'show_ui' => true,
            'show_admin_column' => true,
            'query_let' => true,
            'has_archive' => true,
            'rewrite' => array('slug' => $portfolio_slug . '/categories'),
        ));

        /* register portfolio post type */
        register_post_type('portfolio', [
            'label' => null,
            'labels' => [
                'name' => esc_html__('Portfolio', 'jkd-core'),
                'singular_name' => esc_html__('Portfolio Item', 'jkd-core'),
                'add_new' => esc_html__('Add New', 'jkd-core'),
                'add_new_item' => esc_html__('Add New Item', 'jkd-core'),
                'edit_item' => esc_html__('Edit Item', 'jkd-core'),
                'new_item' => esc_html__('New Item', 'jkd-core'),
                'view_item' => esc_html__('View Item', 'jkd-core'),
                'search_items' => esc_html__('Search Item', 'jkd-core'),
                'not_found' => esc_html__('Not Found', 'jkd-core'),
                'not_found_in_trash' => esc_html__('Not Found in Trash', 'jkd-core'),
                'menu_name' => esc_html__('Portfolio', 'jkd-core'),
            ],
            'description' => '',
            'public' => true,
            'show_in_menu' => null,
            'show_in_rest' => true,
            'rest_base' => null,
            'menu_position' => null,
            'menu_icon' => 'dashicons-layout',
            'hierarchical' => true,
            'supports' => ['title', 'editor', 'author', 'thumbnail', 'excerpt', 'comments'],
            'taxonomies' => array('portfolio-categories', 'portfolio-tags'),
            'has_archive' => true,
            'query_let' => true,
            'rewrite' => array('slug' => $portfolio_slug),
        ]);

    }

    /**
     * ajax handler : categories
     */
    public function ajax_categories()
    {

        /* category slug */
        $category_query = $_POST['category'];

        /* paged */
        $paged = $_POST['paged'] ? $paged = $_POST['paged'] : 1;

        /* posts per page */
        $posts_per_page = get_theme_mod('portfolio-archive-number-of-items', 9);

        /* portfolio args */
        $portfolio_args = array(
            'order' => 'DESC',
            'post_type' => 'portfolio',
            'ignore_sticky_posts' => 1,
            'posts_per_page' => $posts_per_page,
            'paged' => $paged,
        );

        /* check if category query exists */
        if (!empty($category_query) && $category_query !== '*'):

            /* add tax query portfolio categories */
            $portfolio_args['tax_query'] = array(
                array(
                    'taxonomy' => 'portfolio-categories',
                    'field' => 'slug',
                    'terms' => $category_query,
                )
            );

        endif;

        /* register portfolio query */
        $portfolio_query = new WP_Query($portfolio_args);

        if (!empty($portfolio_query)):

            /* portfolio query loop */
            if ($portfolio_query->have_posts()) :

                while ($portfolio_query->have_posts()) : $portfolio_query->the_post();

                    /* item render */
                    JKD_Core::template('portfolio/grid/item');

                endwhile;

            endif;

        endif;

        die();

    }

    /**
     * ajax handler : webgl slider load more
     */
    public function ajax_webgl_slider_load_more()
    {

        /* get counter */
        $counter = $_POST['counter'] ? $_POST['counter'] : 1;

        $atts = array();

        if (!empty($counter)):

            $atts['counter'] = $counter;

            /* get paged */
            $paged = (int)$_POST['paged'] ? (int)$_POST['paged'] : 1;

            if (!empty($paged)):

                /* portfolio args */
                $portfolio_args = array(
                    'order' => 'DESC',
                    'post_type' => 'portfolio',
                    'ignore_sticky_posts' => 1,
                    'posts_per_page' => (int)get_theme_mod('portfolio-front-items-count', 9),
                    'paged' => $paged,
                );

                /* portfolio wp query */
                $portfolio_query = new WP_Query($portfolio_args);

                if (!empty($portfolio_query)):

                    ?>

                    <!-- slides wrapper -->
                    <div class="slides-wrapper">

                        <?php

                        /* portfolio loop */
                        if ($portfolio_query->have_posts()) :

                            while ($portfolio_query->have_posts()) : $portfolio_query->the_post();

                                JKD_Core::template('front-scene/webgl-slider/item', $atts);

                                $atts['counter']++;

                            endwhile;

                        endif;

                        ?>

                    </div>

                <?php

                endif;

            endif;

        endif;

        die();

    }

    /**
     * ajax handler : load more
     */
    public function ajax_grid_load_more()
    {

        /* get category */
        $category = $_POST['category'];

        /* get tag */
        $tag = $_POST['tag'];

        /* get category query */
        $category_query = $_POST['category_query'];

        /* get paged */
        $paged = $_POST['paged'] ? $_POST['paged'] : 1;

        /* get posts per page */
        $posts_per_page = get_theme_mod('portfolio-archive-number-of-items', 9);

        /* portfolio args */
        $portfolio_args = array(
            'order' => 'DESC',
            'post_type' => 'portfolio',
            'ignore_sticky_posts' => 1,
            'posts_per_page' => $posts_per_page,
            'paged' => $paged,
        );

        /* check if category query is empty or === * (all) */
        if (!empty($category_query) && $category_query !== '*'):

            /* push tax_query to portfolio args */
            $portfolio_args['tax_query'] = array(
                array(
                    'taxonomy' => 'portfolio-categories',
                    'field' => 'slug',
                    'terms' => $category_query,
                )
            );

        endif;

        /* check if category is empty */
        if (!empty($category)):

            /* push tax_query to portfolio args */
            $portfolio_args['tax_query'] = array(
                array(
                    'taxonomy' => 'portfolio-categories',
                    'field' => 'slug',
                    'terms' => $category,
                )
            );

        endif;

        /* check if tag is empty */
        if (!empty($tag)):

            /* push tax_query to portfolio args */
            $portfolio_args['tax_query'] = array(
                array(
                    'taxonomy' => 'portfolio-tags',
                    'field' => 'slug',
                    'terms' => $tag,
                )
            );

        endif;

        /* portfolio query */
        $portfolio_query = new WP_Query($portfolio_args);

        if (!empty($portfolio_args)):

            /* portfolio query loop */
            if ($portfolio_query->have_posts()) :

                while ($portfolio_query->have_posts()) : $portfolio_query->the_post();

                    /* item render */
                    JKD_Core::template('portfolio/grid/item');

                endwhile;

            endif;

        endif;

        die();

    }

}
