<?php defined('ABSPATH') || exit;
/*
 *
 */

$blog_display_date = get_theme_mod('blog-display-date', 1);

$blog_display_category_label = get_theme_mod('blog-display-category-label', 1);

$blog_display_author = get_theme_mod('blog-display-author', 1);

$blog_display_excerpt = get_theme_mod('blog-display-excerpt', 1);

if ($blog_display_author):

    $author_id = get_the_author_meta('ID');

    $author_name = get_the_author();

    $author_url = get_author_posts_url($author_id);

    $author_avatar_url = get_avatar_url($author_id);

endif;

/* get title */
$title = get_the_title();

/* get excerpt */
$excerpt = get_the_excerpt();

$excerpt = str_replace('&nbsp;', '', $excerpt);

/* get tags */
$tags = get_the_tags(get_the_ID());

/* get categories */
$categories = get_the_category(get_the_ID());

/* get date */
$date = get_the_date();

/* get post format */
$post_format = get_post_format();

?>

<!-- post-article -->
<article <?php post_class('post-article post-article-hidden'); ?> id="<?php echo esc_attr('post-' . get_the_ID()); ?>">

    <!-- post-inner -->
    <div class="post-inner">

        <?php

        /* check if title is empty */
        if (!empty($title)):

            ?>

            <!-- title-wrapper -->
            <div class="title-wrapper">

                <!-- title -->
                <h2 class="title">

                    <!-- title link -->
                    <a href="<?php the_permalink(); ?>" class="multiline-hover">

                        <?php

                        /* echo title */
                        echo esc_html(wp_trim_words($title, 10, '...'));

                        ?>

                    </a>

                </h2>

            </div>

        <?php endif; ?>

        <?php

        /* check if excerpt is empty */
        if (!empty($excerpt)):

            ?>

            <!-- excerpt-wrapper -->
            <div class="excerpt-wrapper">

                <!-- excerpt -->
                <p class="excerpt">

                    <?php

                    /* echo excerpt */
                    echo esc_html(wp_trim_words($excerpt, 30, '...'));

                    ?>

                </p>

            </div>

        <?php endif; ?>

        <?php if (!empty(get_the_permalink())): ?>

            <!-- load-more-wrapper -->
            <div class="load-more-wrapper">

                <!-- read-more-link -->
                <a href="<?php the_permalink(); ?>" class="jkd-button default-border-style animation-fill">

                    <?php echo esc_html__('Read More', 'jkd-core'); ?>

                </a>

            </div>

        <?php endif; ?>

        <?php

        /* check if categories || date is empty */
        if (!empty($categories[0]) || !empty($date)):

            ?>

            <!--meta-list -->
            <ul class="meta-list">

                <?php

                /* check if categories is empty */
                if (!empty($categories[0])):

                    ?>

                    <!-- category-item -->
                    <li class="category-item meta-item">

                        <i class="ri-price-tag-3-line"></i>

                        <?php

                        /* echo category prefix title */
                        echo esc_html__('Category: ', 'jkd-core');

                        ?>

                        <!--category link  -->
                        <a href="<?php echo esc_url(get_term_link($categories[0]->term_id)); ?>">

                            <?php

                            // echo category name
                            echo esc_html($categories[0]->name);

                            ?>

                        </a>

                    </li>

                <?php endif; ?>

                <?php

                /* check if date is empty  */
                if (!empty($date)):

                    ?>

                    <!-- meta-item -->
                    <li class="date-item meta-item">

                        <i class="ri-calendar-line"></i>

                        <?php

                        /* echo date */
                        echo esc_html($date);

                        ?>

                    </li>

                <?php endif; ?>

                <li class="meta-item post-format-item">

                    <?php if ($post_format === 'aside'): ?>

                        <i class="ri-edit-line"></i>

                        <?php echo esc_html__('Aside', 'jkd-core'); ?>

                    <?php elseif ($post_format === 'audio'): ?>

                        <i class="ri-music-2-line"></i>

                        <?php echo esc_html__('Audio', 'jkd-core'); ?>

                    <?php elseif ($post_format === 'gallery'): ?>

                        <i class="ri-gallery-line"></i>

                        <?php echo esc_html__('Gallery', 'jkd-core'); ?>

                    <?php elseif ($post_format === 'image'): ?>

                        <i class="ri-image-line"></i>

                        <?php echo esc_html__('Image', 'jkd-core'); ?>

                    <?php elseif ($post_format === 'link'): ?>

                        <i class="ri-link"></i>

                        <?php echo esc_html__('Link', 'jkd-core'); ?>

                    <?php elseif ($post_format === 'quote'): ?>

                        <i class="ri-double-quotes-l"></i>

                        <?php echo esc_html__('Quote', 'jkd-core'); ?>

                    <?php elseif ($post_format === 'video'): ?>

                        <i class="ri-play-mini-line"></i>

                        <?php echo esc_html__('Video', 'jkd-core'); ?>

                    <?php else: ?>

                        <i class="ri-file-text-line"></i>

                        <?php echo esc_html__('Standard', 'jkd-core'); ?>

                    <?php endif; ?>

                </li>

                <?php if (is_sticky()): ?>

                    <!-- meta-item -->
                    <li class="sticky-item meta-item">

                        <i class="ri-pushpin-2-line"></i>

                        <?php

                        /* echo sticky post message */
                        echo esc_html__('Sticky Post', 'jkd-core');

                        ?>

                    </li>

                <?php endif; ?>

            </ul>

        <?php endif; ?>

    </div>

</article>
