<?php if (!defined('ABSPATH')) : exit; endif;

/**
 * Class jkd_accordions_widget
 */
class jkd_accordions_widget extends \Elementor\Widget_Base
{

    /**
     * jkd_accordions_widget constructor.
     *
     * @param array $data
     * @param null $args
     *
     * @throws Exception
     */
    public function __construct($data = [], $args = null)
    {

        parent::__construct($data, $args);

    }

    /**
     * @return string
     */
    public function get_name()
    {

        return 'jk-accordion';

    }

    /**
     * @return string|void
     */
    public function get_title()
    {

        return __('Accordions', 'jkd-core');

    }

    /**
     * @return string
     */
    public function get_icon()
    {

        return 'eicon-accordion';

    }

    /**
     * @return array
     */
    public function get_categories()
    {

        return ['jkd-widgets'];

    }

    /**
     *
     */
    protected function register_controls()
    {

        $this->start_controls_section(
            'content_section',
            [
                'label' => __('Settings', 'jkd-core'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'accordion_title',
            [
                'label' => __('Title', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Accordion Title', 'jkd-core'),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'accordion_content',
            [
                'label' => __('Content', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::WYSIWYG,
                'default' => __('Accordion Content', 'jkd-core'),
                'show_label' => false,
            ]
        );

        $this->add_control(
            'accordion',
            [
                'label' => __('Accordion', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'accordion_title' => __('Accordion title', 'jkd-core'),
                        'accordion_content' => __('Item content. Click the edit button to change this text.', 'jkd-core'),
                    ],
                    [
                        'accordion_title' => __('Accordion title', 'jkd-core'),
                        'accordion_content' => __('Item content. Click the edit button to change this text.', 'jkd-core'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     *
     */
    protected function render()
    {

        wp_enqueue_script(JKD_Core::$prefix . 'accordions');

        wp_enqueue_style(JKD_Core::$prefix . 'accordions');

        $settings = $this->get_settings_for_display();

        $counter_trigger = false;

        if (!empty($settings['accordion'])):

            ?>

            <ul class="jkd-accordion">

                <?php foreach ($settings['accordion'] as $item) : ?>

                    <?php if (!empty($item['accordion_title'])): ?>

                        <li class="accordion-item <?php if (!$counter_trigger): ?> open <?php endif; ?>">

                            <div class="open-link">

                                <i class="ri-arrow-down-s-line arrow-icon"></i>

                                <h6 class="accordion-title">

                                    <?php echo esc_html($item['accordion_title']); ?>

                                </h6>

                            </div>

                            <?php if (!empty($item['accordion_content'])): ?>

                                <div class="accordion-content">

                                    <?php echo $item['accordion_content']; ?>

                                </div>

                            <?php endif; ?>

                        </li>

                        <?php $counter_trigger = true; ?>

                    <?php endif; ?>

                <?php endforeach; ?>

            </ul>

        <?php

        endif;

    }
}
