<?php if (!defined('ABSPATH')) : exit; endif;
/*
 *
 */

/**
 * Class JKD_Button_Widget
 */
class jkd_button_widget extends \Elementor\Widget_Base
{

    /**
     * @return string
     */
    public function get_name()
    {
        return 'jk-button';
    }

    /**
     * @return string|void
     */
    public function get_title()
    {
        return __('Button', 'jkd-core');
    }

    /**
     * @return string
     */
    public function get_icon()
    {
        return 'eicon-button';
    }

    /**
     * @return array
     */
    public function get_categories()
    {
        return ['jkd-widgets'];
    }

    /**
     *
     */
    protected function register_controls()
    {

        $this->start_controls_section(
            'content_section',
            [
                'label' => __('Settings', 'jkd-core'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'button_style',
            [
                'label' => __('Button Style', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'default-style' => __('Default Style', 'jkd-core'),
                    'default-border-style' => __('Default Border Style', 'jkd-core'),
                    'white-style' => __('White Style', 'jkd-core'),
                    'white-border-style' => __('White Border Style', 'jkd-core'),
                ],
                'default' => 'default-style'
            ]
        );

        $this->add_control(
            'button_size',
            [
                'label' => __('Button Size', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'size-extra-large' => __('Extra Large', 'jkd-core'),
                    'size-large' => __('Large', 'jkd-core'),
                    'size-default' => __('Default', 'jkd-core'),
                    'size-small' => __('Small', 'jkd-core'),
                    'size-extra-small' => __('Extra Small', 'jkd-core'),
                ],
                'default' => 'size-default'
            ]
        );

        $this->add_control(
            'button_hover_style',
            [
                'label' => __('Hover Style', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'animation-fill' => __('Fill', 'jkd-core'),
                    'animation-slide' => __('Slide', 'jkd-core'),
                ],
                'default' => 'animation-fill'
            ]
        );

        $this->add_control(
            'button_text',
            [
                'label' => __('Button Text', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Button', 'jkd-core'),
                'placeholder' => __('Button', 'jkd-core'),
            ]
        );

        $this->add_control(
            'button_link',
            [
                'label' => __('Button Link', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __('', 'jkd-core'),
                'show_external' => true,
                'default' => [
                    'url' => '',
                    'is_external' => true,
                    'nofollow' => true,
                ],
            ]
        );

        $this->add_control(
            'target_type',
            [
                'label' => __('Target type', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'description' => __('Select the type of target, depending on the value, the link will be opened in the current window (_self) or in a new one (_blank)', 'jkd-core'),
                'multiple' => false,
                'options' => [
                    '_self' => __('Self', 'jkd-core'),
                    '_blank' => __('Blank', 'jkd-core'),
                ],
                'default' => '_self',
            ]
        );

        $this->end_controls_section();

    }

    /**
     *
     */
    protected function render()
    {

        $settings = $this->get_settings_for_display();

        $id = $this->get_id();

        $classes = array();

        $style = $settings['button_style'];

        $hover = $settings['button_hover_style'];

        $size = $settings['button_size'];

        array_push($classes, $style);

        array_push($classes, $hover);

        array_push($classes, $size);

        $classes = implode(' ', $classes);

        $text = $settings['button_text'];

        if (!empty($text)):

            ?>

            <div class="button-wrapper">

                <a href="<?php echo esc_url($settings['button_link']['url']); ?>"
                   class="jkd-button <?php echo esc_attr($classes); ?>"
                   target="<?php echo esc_attr($settings['target_type']); ?>">

              <span>

                  <span>

                        <?php echo esc_html($text); ?>

                  </span>

              </span>

                </a>

            </div>

        <?php

        endif;

    }
}
