<?php if (!defined('ABSPATH')) : exit; endif;
/*
 *
 */

/**
 * Class jkd_career_list_widget
 */
class jkd_career_list_widget extends \Elementor\Widget_Base
{

    /**
     * jkd_ticker_text_widget constructor.
     *
     * @param array $data
     * @param null $args
     *
     * @throws Exception
     */
    public function __construct($data = [], $args = null)
    {

        parent::__construct($data, $args);

    }

    /**
     * @return string
     */
    public function get_name()
    {
        return 'jk-career-list-widget';
    }

    /**
     * @return string|void
     */
    public function get_title()
    {
        return __('Career List', 'jkd-core');
    }

    /**
     * @return string
     */
    public function get_icon()
    {
        return 'eicon-bullet-list';
    }

    /**
     * @return array
     */
    public function get_categories()
    {
        return ['jkd-widgets'];
    }

    /**
     *
     */
    protected function register_controls()
    {

        $this->start_controls_section(
            'content_section',
            [
                'label' => __('Settings', 'jkd-core'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'positions_count',
            [
                'label' => __('Positions Count', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'default' => [
                    'size' => 4,
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     *
     */
    protected function render()
    {

        wp_enqueue_script(JKD_Core::$prefix . 'career');

        wp_enqueue_style(JKD_Core::$prefix . 'career');

        $settings = $this->get_settings_for_display();

        $id = $this->get_id();

        $args = array(
            'posts_per_page' => $settings['positions_count']['size'],
            'order' => 'DESC',
            'post_type' => 'career',
            'post__not_in' => array(get_the_ID()),
        );

        $the_query = new WP_Query($args);

        if ($the_query->have_posts()) :

            ?>

            <div class="positions-list">

                <?php while ($the_query->have_posts()) : $the_query->the_post(); ?>

                    <?php

                    $title = get_the_title();

                    $field_position_location = JKD_Helper::get_field('field_position_location');

                    $field_position_category = JKD_Helper::get_field('field_position_category');

                    if (!empty($title) || !empty($field_position_location) || !empty($field_position_category)):

                        ?>

                        <article <?php post_class('position-item'); ?>>

                            <div class="item-inner">

                                <div class="title-side">

                                    <?php if (!empty($field_position_category)): ?>

                                        <p class="position-category">

                                            <?php echo esc_html($field_position_category); ?>

                                        </p>

                                    <?php endif; ?>

                                    <?php if (!empty($title)): ?>

                                        <h5 class="post-title">

                                            <a href="<?php the_permalink(); ?>" class="multiline-hover">

                                                <?php echo esc_html(wp_trim_words($title, 7, '...')); ?>

                                            </a>

                                        </h5>

                                    <?php endif; ?>

                                </div>

                                <?php if (!empty($field_position_location)): ?>

                                    <div class="location-side">

                                        <p class="location">

                                            <i class="ri-map-pin-line"></i>

                                            <span>

                                        <?php echo esc_html($field_position_location); ?>

                                  </span>

                                        </p>

                                    </div>

                                <?php endif; ?>

                            </div>

                        </article>

                    <?php endif; ?>

                <?php endwhile; ?>

            </div>

        <?php

        endif;

    }
}
