<?php if (!defined('ABSPATH')) : exit; endif;
/*
 *
 */

/**
 * Class JKD_Button_Widget
 */
class jkd_paroller_image_widget extends \Elementor\Widget_Base
{

    /**
     * jkd_paroller_image_widget constructor.
     *
     * @param array $data
     * @param null $args
     *
     * @throws Exception
     */
    public function __construct($data = [], $args = null)
    {
        parent::__construct($data, $args);


    }

    /**
     * @return string
     */
    public function get_name()
    {
        return 'jk-paroller';
    }

    /**
     * @return string|void
     */
    public function get_title()
    {
        return __('Paroller Image', 'jkd-core');
    }

    /**
     * @return string
     */
    public function get_icon()
    {
        return 'eicon-image';
    }

    /**
     * @return array
     */
    public function get_categories()
    {
        return ['jkd-widgets'];
    }

    /**
     *
     */
    protected function register_controls()
    {

        $this->start_controls_section(
            'content_section',
            [
                'label' => __('Settings', 'jkd-core'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'image',
            [
                'label' => __('Choose Image', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Image_Size::get_type(),
            [
                'name' => 'image_size',
                'label' => __('Image Size', 'jkd-core'),
                'default' => 'large',
            ]
        );

        $this->add_control(
            'paroller_direction',
            [
                'label' => __('Paroller Direction', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'vertical' => [
                        'title' => __('Vertical', 'jkd-core'),
                        'icon' => 'eicon-navigation-vertical',
                    ],
                    'horizontal' => [
                        'title' => __('Horizontal', 'jkd-core'),
                        'icon' => 'eicon-navigation-horizontal',
                    ],
                ],
                'default' => 'vertical',
            ]
        );

        $this->add_control(
            'paroller_factor',
            [
                'label' => __('Paroller Factor', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'default' => [
                    'size' => 10,
                ],
            ]
        );

        $this->add_control(
            'paroller_factor_xs',
            [
                'label' => __('Paroller Factor XS', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'default' => [
                    'size' => 10,
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     *
     */
    protected function render()
    {

        wp_enqueue_script(JKD_Core::$prefix . 'paroller-lib');

        wp_enqueue_script(JKD_Core::$prefix . 'paroller');

        wp_enqueue_style(JKD_Core::$prefix . 'paroller');

        $settings = $this->get_settings_for_display();

        $id = $this->get_id();

        $settings = $this->get_settings();

        $image = $settings['image'];

        $size = $settings['image_size_size'];

        $image_url = wp_get_attachment_image_url($image['id'], $size);

        if (!empty($image_url)):

            ?>

            <img class="paroller-image" src="<?php echo esc_url($image_url); ?>"
                 alt="<?php echo esc_attr__('Paroller Image', 'jkd-core'); ?>"
                 data-paroller-factor="<?php echo esc_attr($settings['paroller_factor']['size'] / 100); ?>"
                 data-paroller-factor-xs="<?php echo esc_attr($settings['paroller_factor_xs']['size'] / 100); ?>"
                 data-paroller-direction="<?php echo esc_attr($settings['paroller_direction']); ?>"
                 data-paroller-type="foreground">

        <?php

        endif;

    }
}
