<?php defined('ABSPATH') || exit;

/*
 *
 */

/**
 * Class jkd_team_member_widget
 */
class jkd_team_member_widget extends \Elementor\Widget_Base
{

    /**
     * @return string
     */
    public function get_name()
    {

        /* return widget name (slug) */
        return 'jk-team-member';

    }

    /**
     * @return string|void
     */
    public function get_title()
    {

        /* return widget title */
        return esc_attr__('Team Member', 'jkd-core');

    }

    /**
     * @return string
     */
    public function get_icon()
    {

        /* return icon */
        return 'eicon-lock-user';

    }

    /**
     * @return array
     */
    public function get_categories()
    {

        /* return jk category */
        return ['jkd-widgets'];

    }

    /**
     * register controls
     */
    protected function register_controls()
    {

        $this->start_controls_section(
            'team_member_options',
            [
                'label' => __('Team Member Options', 'jkd-core'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'member_image',
            [
                'label' => __('Choose Image', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'member_name',
            [
                'label' => __('Member Name', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
            ]
        );

        $this->add_control(
            'member_position',
            [
                'label' => __('Member Position', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'item_title',
            [
                'label' => __('Item title', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => __('Type your title here', 'jkd-core'),
            ]
        );

        $repeater->add_control(
            'item_link',
            [
                'label' => __('Item Link', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __('Type your link here', 'jkd-core'),
            ]
        );

        $this->add_control(
            'social_list',
            [
                'label' => __('Social list', 'jkd-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            ]
        );

        $this->end_controls_section();

    }

    /**
     * render widget
     */
    protected function render()
    {

        /* array of widget settings */
        $settings = $this->get_settings_for_display();

        /* widget id */
        $id = $this->get_id();

        $image = $settings['member_image'];

        $name = $settings['member_name'];

        $position = $settings['member_position'];

        $image_url = wp_get_attachment_image_url($image['id'], 'jk-vertical-size-small');

        $social_list = $settings['social_list'];

        if (!empty($image)):

            ?>

            <div class="team-member">

                <div class="member-image-wrapper image-wrapper">

                    <?php if (!empty($image_url)): ?>

                        <img src="<?php echo esc_url($image_url); ?>" alt="<?php echo esc_attr($name); ?>">

                    <?php endif; ?>

                    <?php if (!empty($social_list)) : ?>

                        <ul class="social-list">

                            <?php foreach ($social_list as $item): ?>

                                <?php if ($item['item_title']): ?>

                                    <li class="list-item">

                                        <a href="<?php echo esc_url($item['item_link']['url']); ?>" class="social-box"
                                            <?php echo esc_attr($item['item_link']['is_external'] ? ' target="_blank"' : ''); ?> <?php echo esc_attr($item['item_link']['nofollow'] ? ' rel="nofollow"' : ''); ?>>

                                            <?php if ($item['item_title']): ?>

                                                <span class="social-title">

                                        <?php echo esc_attr($item['item_title']); ?>

                                    </span>

                                            <?php endif; ?>

                                        </a>

                                    </li>

                                <?php endif; ?>

                            <?php endforeach; ?>

                        </ul>

                    <?php endif; ?>

                </div>

                <?php if (!empty($name)): ?>

                    <h5 class="member-name">

                        <?php echo esc_html($name); ?>

                    </h5>

                <?php endif; ?>

                <?php if (!empty($position)): ?>

                    <p class="member-position">

                        <?php echo esc_html($position); ?>

                    </p>

                <?php endif; ?>

            </div>

        <?php

        endif;

    }
}
